function w = addLOS(win, theta, phi, A, alpha)
%ADDLOS Add LOS Line-of-sight component to environment.
%
%   function w = addLOS(win, theta, phi, A, alpha)
%
%   Add a line-of-sight (LOS) component to the waves "w" (or clusters). The LOS
%   component is coming from the "theta" and "phi" angles and is always linear
%   polarized (with phase zero). It has the peak amplitude "A" and angle "alpha"
%   between the theta and phi unit vectors.

% By Ulf Carlberg.

if isempty(win) % create new structure with only LOS
    w.envType = 'LOS';
    w.theta   = zeros(0, 1);
    w.phi     = zeros(0, 1);
    w.E_theta = zeros(0, 1);
    w.E_phi   = zeros(0, 1);
    w.nWavesPerRealization = 0;
    w.nRealizations = 1;
else % copy structure
    w = win;
end

% Add LOS component to wave or cluster structure. (An identical LOS component is
% added to each realization.)
M = size(w.E_theta, 2);
if isfield(w, 'theta') % waves
    w.theta = [w.theta ; repmat(theta, 1, M)];
    w.phi   = [w.phi   ; repmat(phi  , 1, M)];
    w.nWavesPerRealization = w.nWavesPerRealization + 1;
else % clusters
    [x, y, z] = rthetaphi2xyz(1e8, theta, phi);
    w.x = [w.x ; repmat(x, 1, M)];
    w.y = [w.y ; repmat(y, 1, M)];
    w.z = [w.z ; repmat(z, 1, M)];
    w.nPoints = w.nPoints + 1;
end
w.E_theta = [w.E_theta ; repmat(A*cos(alpha), 1, M)];
w.E_phi   = [w.E_phi   ; repmat(A*sin(alpha), 1, M)];
