function y = calc_bins(x, edges)
%CALC_BINS Calculate which bins (defined by edges) the elements of a matrix belongs to. 
%
%   function y = calc_bins(x, edges)
%
%   Calculate which bins the elements in matrix "x" belongs to. The bins are
%   defined by the edges.
%
%   Example: calc_bins(magic(10), [10 20])
%
%   See also HISTC.

% By Ulf Carlberg.

% Check input.
assert(ndims(edges)==2 && size(edges, 1)==1, 'Edges must be a column vector.');
assert(all(diff(edges)>0), 'Edges must be increasing.');

% Calculate which bin every element belongs to.
y = zeros(size(x));
for i = 1:length(edges)
    y(x>=edges(i)) = i;
end
