function v2 = combine_antenna_ports(v, weights)
%COMBINE_ANTENNA_PORTS Combine antenna port receive voltages with weights.
%
%   function v2 = combine_antenna_ports(v, weights)
%
%   Combine antenna port receive voltages.

% By Ulf Carlberg.

% Check dimensions.
assert(ndims(weights)==2, 'Wrong size of weights. Must be a 2-D matrix.');
assert(size(weights, 2)==size(v, 3), ...
    'Wrong size of weights. nColumns must be equal to size(v, 3).');

% Normalize weights so that the total power received is constant.
weights = weights ./ ...
    repmat(sqrt(sum(weights.^2, 2)./size(weights, 2)), 1, size(weights, 2));

% Calculate new voltages.
siz = size(v);
siz(3) = size(weights, 1);
v2 = complex(zeros(siz));
for ii = 1:size(v2, 3)
    for jj = 1:size(v, 3)
        v2(:, :, ii, :) = v2(:, :, ii, :) + weights(ii, jj)*v(:, :, jj, :);
    end
end
