function y = cummean(x, dim)
%CUMMEAN Cumulative mean.
%
%   function y = cummean(x, dim)
%
%   Cumulative mean of "x" over dimension "dim". If the dimension is not
%   specified, the cumulative mean is calculated over the first non-singleton
%   dimension.
%
%   See also CUMSUM, MEAN, SUM.

% By Ulf Carlberg.

% If "dim" is not specified, use the first non-singleton dimension.
if nargin<2
    dim = find(size(x)~=1, 1);
    if isempty(dim), dim = 1; end
end

y = cumsum(x, dim) ./ cumsum(ones(size(x)), dim);
