function v2 = diversity(divTechnique, v)
%DIVERSITY Diversity (SC, selection combining, MRC, maximum-ratio combining) calculation of received voltages.
%
%   function v2 = diversity(divTechnique, v)
%
%   Returns diversity voltages "v2" from the voltages "v" using diversity
%   technique "divTechnique". The different antenna ports are assumed to be on
%   dimension 3 of "v".
%
%   "divTechnique" can be:
%   'sc'  - selction combining
%   'mrc' - maximum ratio combining 

% By Ulf Carlberg.

if strcmpi(divTechnique, 'sc')
    v2 = max(v, [], 3);
elseif strcmpi(divTechnique, 'mrc')
    v2 = sqrt(sum(abs(v).^2, 3));
else
    error('Unknown diversity technique.');
end
