close all;
clear;

reset(RandStream.getGlobalStream, 123);
N = 1e4;
basefilename = [mfilename '_'];
saveplots = 0;

% 3D Environment.
case3D.w = gen_waves('3D', 20, N, 'Linear');
case3D.p = gen_positions(0, 0, 0, 0, [0 pi/4 pi/2], 0);
case3D.a = [gen_farfield('incremental electric dipole') ...
            gen_farfield('incremental electric dipole') ...
            gen_farfield('incremental electric dipole')];

% 2D Environment.
case2D.w = gen_waves('2D', 20, N, 'Linear');
case2D.p = case3D.p;
case2D.a = case3D.a;

% Calculate all the parameters.
nSamplesVector = unique(round(logspace(log10(10),log10(N),1000)));
case3D = calc(case3D,nSamplesVector,1,3);
case2D = calc(case2D,nSamplesVector,1,3);

% MED
figure;
semilogx(case3D.nSamplesVector, 10*log10([case3D.med case2D.med].'), ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) -9 0]);
grid on;
title('Estimated Mean Effective Directivity');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated MED [dB]');
legend('Vertical Dipole 3D', 'Tilted 45 deg Dipole 3D', ...
    'Horizontal Dipole 3D', 'Vertical Dipole 2D', 'Tilted 45 deg Dipole 2D', ...
    'Horizontal Dipole 2D', 'Location', 'southeast');
if saveplots, save_fig([basefilename 'MED.png']); end

% Correlation
figure;
semilogx(case3D.nSamplesVector, abs([case3D.correlation(:,:) ...
    case2D.correlation(:,:)].'), 'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 0 1]);
grid on;
title('Estimated Correlation');
xlabel('Cumulative Number of Samples [-]');
ylabel('Correlation [-]');
if saveplots, save_fig([basefilename 'correlation.png']); end

% ADG
figure;
semilogx(case3D.nSamplesVector, 10*log10([case3D.adg3 case2D.adg3].'), ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 0 12]);
grid on;
title('Estimated Apparent Diversity Gain');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Apparent Diversity Gain [dB]');
if saveplots, save_fig([basefilename 'ADG.png']); end

% Capacity
figure;
semilogx(case3D.nSamplesVector, [case3D.capacity case2D.capacity].', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 2 9]);
grid on;
title('Estimated Capacity (for SNR = 15 dB)');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Capacity [bits/s/Hz]');
legend('3D', '2D', 'Location', 'southwest');
if saveplots, save_fig([basefilename 'capacity.png']); end
