% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream,123);

N = 1e4;
basefilename = [mfilename '_'];

% Random positions.
x = 1e6*rand(N,1);
y = 1e6*rand(N,1);
z = 1e6*rand(N,1);
t = rand(1000,1);
alpha = 2*pi*xmat(rand(1000,1),N);
theta = xmat(acos(1-2*rand(1000,1)),N);
phi = 2*pi*xmat(rand(1000,1),N);

% Environments.
w3D = gen_waves('3D', 20, 1, 'Linear');
w2D = gen_waves('2D', 20, 1, 'Linear');

% Positions.
p = gen_positions([x x], y, z, alpha, theta, phi);

% Far-fields.
aDip1  = gen_farfield('incremental electric dipole');
aDip2  = rotate_farfield(aDip1,0,pi/2,0);
aCosn1 = gen_farfield('cosn 45');
aCosn2 = rotate_farfield(aCosn1,pi/2,0,0);

% Cases.
case3Ddip  = struct('w', w3D, 'p', p, 'a', [aDip1  aDip2 ]);
case3Dcosn = struct('w', w3D, 'p', p, 'a', [aCosn1 aCosn2]);
case2Ddip  = struct('w', w2D, 'p', p, 'a', [aDip1  aDip2 ]);
case2Dcosn = struct('w', w2D, 'p', p, 'a', [aCosn1 aCosn2]);

% Calculate all the parameters.
nSamplesVector = unique(round(logspace(log10(10), log10(N), 50)));
case3Ddip  = calc(case3Ddip , nSamplesVector, 1, 2);
case3Dcosn = calc(case3Dcosn, nSamplesVector, 1, 2);
case2Ddip  = calc(case2Ddip , nSamplesVector, 1, 2);
case2Dcosn = calc(case2Dcosn, nSamplesVector, 1, 2);



% Plot

% MED
figure;
semilogx(case3Ddip.nSamplesVector,10*log10( ...
    [case3Ddip.med case3Dcosn.med].'), ...
    '.-', 'linewidth', 1);
hold on;
semilogx(case3Ddip.nSamplesVector,10*log10( ...
    [case2Ddip.med case2Dcosn.med].'), ...
    '-', 'linewidth', 1);
axis([0 max(case3Ddip.nSamplesVector) -12 0]);
title('Estimated Mean Effective Directivity');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated MED [dB]');
legend('3D Env., Dipole 1', ...
       '3D Env., Dipole 2', ...
       '3D Env., Pencil Beam 1', ...
       '3D Env., Pencil Beam 2', ...
       '2D Env., Dipole 1', ...
       '2D Env., Dipole 2', ...
       '2D Env., Pencil Beam 1', ...
       '2D Env., Pencil Beam 2', ...
       'Location', 'southwest');
%save_fig([basefilename 'MED.png'],12);

% ADG
figure;
semilogx(case3Ddip.nSamplesVector, 10*log10(...
    [case3Ddip.adg3 case3Dcosn.adg3 case2Ddip.adg3 case2Dcosn.adg3].'), ...
    'linewidth', 1);
axis([0 max(case3Ddip.nSamplesVector) 0 12]);
title('Estimated Apparent Diversity Gain');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Apparent Diversity Gain [dB]');
legend('3D Env., Dipoles', ...
       '3D Env., Pencil Beams', ...
       '2D Env., Dipoles', ...
       '2D Env., Pencil Beams', ...
       'Location', 'SouthWest');
%save_fig([basefilename 'ADG.png'],12);

% Capacity
figure;
semilogx(case3Ddip.nSamplesVector, [case3Ddip.capacity case3Dcosn.capacity ...
    case2Ddip.capacity case2Dcosn.capacity].', ...
    'linewidth', 1);
axis([0 max(case3Ddip.nSamplesVector) 2 6]);
title('Estimated Capacity (for SNR = 15 dB)');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Capacity [bits/s/Hz]');
legend('3D Env., Dipoles', ...
       '3D Env., Pencil Beams', ...
       '2D Env., Dipoles', ...
       '2D Env., Pencil Beams', ...
       'Location', 'southwest');
%save_fig([basefilename 'capacity.png'],12);
