% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 123);

N = 1e4;
basefilename = [mfilename '_'];

% 3D Environment.
case3D.w = gen_waves('3D', 20, N, 'Linear');
case3D.p = gen_positions(0, [-0.25 0.25], 0, 0, (0:15:90)' * pi/180, 0);
case3D.a = [gen_farfield('incremental electric dipole') ...
            gen_farfield('incremental electric dipole')];

% 2D Environment.
case2D.w = gen_waves('2D', 20, N, 'Linear');
case2D.p = case3D.p;
case2D.a = case3D.a;

% Calculate all the parameters.
nSamplesVector = unique(round(logspace(log10(10),log10(N),1000)));
case3D = calc(case3D,nSamplesVector,1,2);
case2D = calc(case2D,nSamplesVector,1,2);



% Plot

% MED
figure;
semilogx(case3D.nSamplesVector, 10*log10(case3D.med.'), '--', ...
    'linewidth', 1);
hold on;
semilogx(case3D.nSamplesVector, 10*log10(case2D.med.'), '-', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) -9 0]);
grid on;
title('Estimated Mean Effective Directivity'); 
xlabel('Cumulative Number of Samples [-]'); 
ylabel('Estimated MED [dB]'); 
%save_fig([basefilename 'MED.png']);

% Correlation
figure;
semilogx(case3D.nSamplesVector, abs(case3D.correlation(:,:).'), '--', ...
    'linewidth', 1);
hold on;
semilogx(case3D.nSamplesVector, abs(case2D.correlation(:,:).'), '-', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 0 1]);
grid on;
title('Estimated Correlation'); 
xlabel('Cumulative Number of Samples [-]'); 
ylabel('Correlation [-]'); 
%save_fig([basefilename 'correlation.png']);

% ADG
figure;
semilogx(case3D.nSamplesVector, 10*log10(case3D.adg2.'), '--', ...
    'linewidth', 1);
hold on;
semilogx(case3D.nSamplesVector, 10*log10(case2D.adg2.'), '-', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 0 12]);
grid on;
title('Estimated Apparent Diversity Gain'); 
xlabel('Cumulative Number of Samples [-]'); 
ylabel('Estimated Apparent Diversity Gain [dB]'); 
%save_fig([basefilename 'ADG.png']);

% Capacity
figure;
semilogx(case3D.nSamplesVector, case3D.capacity.', '--', ...
    'linewidth', 1);
hold on;
semilogx(case3D.nSamplesVector, case2D.capacity.', '-', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 3 6]);
grid on;
title('Estimated Capacity (for SNR = 15 dB)'); 
xlabel('Cumulative Number of Samples [-]'); 
ylabel('Estimated Capacity [bits/s/Hz]'); 
%save_fig([basefilename 'capacity.png']);
