% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 123);

N = 1e4;
basefilename = [mfilename '_'];

% 3D Environment.
case3D.w = gen_waves('3D', 20, N);
case3D.p = gen_positions(0, 0, 0, 0, (0:15:90)' * pi/180, 0);
case3D.a = gen_farfield('incremental magnetic dipole');

% 2D Environment.
case2D.w = gen_waves('2D', 20, N);
case2D.p = case3D.p;
case2D.a = case3D.a;

% Calculate all the parameters.
nSamplesVector = unique(round(logspace(log10(10),log10(N),1000)));
case3D = calc(case3D,nSamplesVector,1,1);
case2D = calc(case2D,nSamplesVector,1,1);



% Plot

% MED
figure;
semilogx(case3D.nSamplesVector, 10*log10(case3D.med.'), '--', ...
    'linewidth', 1);
hold on;
semilogx(case3D.nSamplesVector, 10*log10(case2D.med.'), '-', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) -9 0]);
grid on;
title('Estimated Mean Effective Directivity');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated MED [dB]');
%save_fig([basefilename 'MED.png']);
