% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream,123);

N = 1e4;
basefilename = [mfilename '_'];

% Environments.
w3D_tx1 = gen_waves('3D', 20, N);
w3D_tx2 = gen_waves('3D', 20, N);

% Positions.
p = gen_positions([0 0], 0, 0, 0, 0, 0);

% Far-fields.
aDip1  = gen_farfield('incremental electric dipole');
aDip2  = rotate_farfield(aDip1,0,pi/2,0);

% Cases.
case3Ddip  = struct('w', w3D_tx1, 'p', p, 'a', [aDip1  aDip2 ]);
case3Ddip  = struct('w', w3D_tx2, 'p', p, 'a', [aDip1  aDip2 ]);

% Calculate all the parameters.
nSamplesVector = unique(round(logspace(log10(10), log10(N), 50)));
case3Ddip  = calc(case3Ddip , nSamplesVector, 1, 2);



% Plot

% MED
figure;
semilogx(case3Ddip.nSamplesVector,10*log10( ...
    case3Ddip.med.'), ...
    '.-', 'linewidth', 1);
axis([0 max(case3Ddip.nSamplesVector) -12 0]);
title('Estimated Mean Effective Directivity');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated MED [dB]');
%save_fig([basefilename 'MED.png'],12);

% ADG
figure;
semilogx(case3Ddip.nSamplesVector, 10*log10(...
    case3Ddip.adg3.'), ...
    'linewidth', 1);
axis([0 max(case3Ddip.nSamplesVector) 0 12]);
title('Estimated Apparent Diversity Gain');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Apparent Diversity Gain [dB]');
%save_fig([basefilename 'ADG.png'],12);

% Capacity
figure;
semilogx(case3Ddip.nSamplesVector, case3Ddip.capacity.', ...
    'linewidth', 1);
axis([0 max(case3Ddip.nSamplesVector) 2 6]);
title('Estimated Capacity (for SNR = 15 dB)');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Capacity [bits/s/Hz]');
%save_fig([basefilename 'capacity.png'],12);
