%% Clear and calculate.
close all;
clear;
drawnow;
%reset(RandStream.getGlobalStream, 123);

N = 1e4;
basefilename = [mfilename '_'];

% Distance between dipoles.
d = 0.5;
nWavesPerRealization = 5;

% 3D Environment.
case3D.w = gen_waves('3D', nWavesPerRealization, N);
case3D.p = gen_positions(0, [-d/2 d/2], 0, 0, 0, 0);
case3D.a = [gen_farfield('incremental electric dipole') ...
            gen_farfield('incremental electric dipole')];

% Calculate all the parameters.
nSamplesVector = unique(round(logspace(log10(10),log10(N),1000)));
case3D = calc(case3D,nSamplesVector,1,2);

% Quick-and-dirty selection combining.
case3D.v(:,:,3) = max(case3D.v,[],3);

%% Plot

% MED
figure;
semilogx(case3D.nSamplesVector, 10*log10(case3D.med.'), '--', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) -9 0]);
grid on;
title('Estimated Mean Effective Directivity');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated MED [dB]');
%save_fig([basefilename 'MED.png']);

% Correlation
figure;
semilogx(case3D.nSamplesVector, abs(case3D.correlation(:,:).'), '--', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 0 1]);
grid on;
title('Estimated Correlation');
xlabel('Cumulative Number of Samples [-]');
ylabel('Correlation [-]');
%save_fig([basefilename 'correlation.png']);

% ADG
figure;
semilogx(case3D.nSamplesVector, 10*log10(case3D.adg1.'), '--', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 0 12]);
grid on;
title('Estimated Apparent Diversity Gain');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Apparent Diversity Gain [dB]');
%save_fig([basefilename 'ADG.png']);

% CDF
figure;
plot_cdf(case3D.v);
%save_fig([basefilename 'CDF.png']);
