%% Clear and calculate.
close all;
clear;
drawnow;
basefilename = [mfilename '_'];

% Move around back-and-forth in a square.
d = -52:52;
[xx, yy] = ndgrid(d, d);
xx(:, 2:2:end) = flipud(xx(:, 2:2:end));
nRows = size(xx, 1);
nCols = size(xx, 2);
N = nRows*nCols;

% Antennas.
a1 = read_farfield_wipld('wipld/two_dipoles.ra1');
a1.f = a1.f(1);
a1.D0 = a1.D0(1);
a1.E_theta = a1.E_theta(:,1);
a1.E_phi = a1.E_phi(:,1);
a2 = rotate_farfield(a1, pi, 0, 0);

% Cluster environment.
cluster.a = [a1 a2];
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));
pstyles1 = {'r-', 'r-', 'r-', 'r-', 'r-'};
pstyles2 = {'b-', 'b-', 'b-', 'b-', 'b-'};

% Isotropic environment.
iso.a = cluster.a;
iso.p = gen_positions([-0.2 0.2], 0, 0, 0, 0, 0);

nWavesOrClusters = 8;

% Cluster environment.
cluster.c = gen_clusters(20, nWavesOrClusters);
cluster.p = gen_positions([xx(:)-0.2 xx(:)+0.2], yy(:), 0, 0, 0, 0);

% Isotropic environment.
iso.w = gen_waves('3D', nWavesOrClusters, N);

figure;
plot_farfield_inpos(iso);
hold on;
plot_farfield_inpos(iso);
%save_fig([basefilename 'farfields.png'], 12);

% Plot isotropic environment.
figure;
plot_waves(iso.w);
%save_fig([basefilename 'isotropic.png'], 12);

% Plot path.
figure;
plot3(xx(:), yy(:), zeros(size(xx(:))), 'k-');
hold on;
plot3(cluster.c.x, cluster.c.y, cluster.c.z, 'r.');
axis equal;
xlabel('x [\lambda]');
ylabel('y [\lambda]');
zlabel('z [\lambda]');
%save_fig([basefilename 'path_and_clusters.png'], 12);
