% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e4;
basefilename = [mfilename '_'];

% Environments.
w3D = gen_waves('3D', 20, N, 'Linear');
w2D = gen_waves('2D', 20, N, 'Linear');

% Positions.
p = gen_positions([0 0], 0, 0, 0, 0, 0);

% Far-fields.
theta = (0:180)*pi/180;
phi = (0:359)*pi/180;
a1 = read_farfield_raw_ascii('11ant/ELANbf3700.dat', ...
    theta, phi);
a2 = rotate_farfield(a1, pi, 0, 0);

% Cases.
case3D = struct('w', w3D, 'p', p, 'a', [a1 a2]);
case2D = struct('w', w2D, 'p', p, 'a', [a1 a2]);

% Calculate all the parameters.
nSamplesVector = unique(round(logspace(log10(10), log10(N), 50)));
case3D = calc(case3D, nSamplesVector, 1, 2);
case2D = calc(case2D, nSamplesVector, 1, 2);


% Plot

% MED
figure;
semilogx(case3D.nSamplesVector,10*log10( ...
    [case3D.med case2D.med].'), ...
    '-', 'linewidth', 1);
axis([0 max(case3D.nSamplesVector) -12 0]);
title('Estimated Mean Effective Directivity');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated MED [dB]');
legend('3D Ant1', '3D Ant2', '2D Ant1', '2D Ant2');
%save_fig([basefilename 'MED.png'],12);

% ADG
figure;
semilogx(case3D.nSamplesVector, 10*log10(...
    [case3D.adg3 case2D.adg3].'), ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 0 12]);
title('Estimated Apparent Diversity Gain');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Apparent Diversity Gain [dB]');
legend('3D', '2D');
%save_fig([basefilename 'ADG.png'],12);

% Capacity
figure;
semilogx(case3D.nSamplesVector, [case3D.capacity case2D.capacity].', ...
    'linewidth', 1);
axis([0 max(case3D.nSamplesVector) 2 6]);
title('Estimated Capacity (for SNR = 15 dB)');
xlabel('Cumulative Number of Samples [-]');
ylabel('Estimated Capacity [bits/s/Hz]');
legend('3D', '2D');
%save_fig([basefilename 'capacity.png'],12);
