% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e4;

% Generate one statistical line-of-sight wave for each realization. The LOS
% component should always have the amplitude one in each realization.
c.w = gen_waves('3D', 1, N, 'Linear');
normFactors = sqrt(abs(c.w.E_theta).^2 + abs(c.w.E_phi).^2);
c.w.E_theta = c.w.E_theta ./ normFactors;
c.w.E_phi = c.w.E_phi ./ normFactors;

%----------------------------------------------------

c.a = gen_farfield('isotropic theta');
c.p = gen_positions(0, 0, 0, 0, 0, 0);
c.v = calc_v(c, 'spline');
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);

%----------------------------------------------------

c.a = gen_farfield('incremental electric dipole');
c.p = gen_positions(0, 0, 0, 0, 0, 0);
c.v = calc_v(c, 'spline');
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);

%----------------------------------------------------

c.a = gen_farfield('incremental Huygens source');
c.v = calc_v(c, 'spline');
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);

%----------------------------------------------------

figure;
c.p = gen_positions([0 0 0 0 0 0], 0, 0, 0, 0, 0);
c.a = [gen_farfield('cosn   5') ...
       gen_farfield('cosn  10') ...
       gen_farfield('cosn  20') ...
       gen_farfield('cosn  40') ...
       gen_farfield('cosn  80') ...
       gen_farfield('cosn 160')];
c.v = calc_v(c, 'spline');
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
legend('Theoretical Rayleigh', ...
       'Half BW =   5 deg', ...
       'Half BW =  10 deg', ...
       'Half BW =  20 deg', ...
       'Half BW =  40 deg', ...
       'Half BW =  80 deg', ...
       'Half BW = 160 deg', ...
       'Location', 'southeast');
