% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e4;

% Generate one statistical line-of-sight wave for each realization. The LOS
% component should always have the amplitude one in each realization.
c.wLOS = gen_waves('3D', 1, N);
normFactors = sqrt(abs(c.wLOS.E_theta).^2 + abs(c.wLOS.E_phi).^2);
c.wLOS.E_theta = c.wLOS.E_theta ./ normFactors;
c.wLOS.E_phi = c.wLOS.E_phi ./ normFactors;

% Generate multipath incoming waves like usual (20/realization).
c.wNLOS = gen_waves('3D', 20, N);

% Two pencil beams pointing in different directions. Note: Not embedded
% patterns!
c.a = [gen_farfield('cosn 40') ...
       gen_farfield('cosn 40')];
c.p = gen_positions(0, 0, 0, 0, [0 pi/2], 0);
figure;
plot_farfield_inpos(c);

% Calculate port voltages for the LOS and NLOS cases separately.
c.w = c.wLOS;
c.vLOS = calc_v(c);
c.w = c.wNLOS;
c.vNLOS = calc_v(c);

% Plot CDF of the LOS and NLOS cases.
figure;
k = randn(N, 1);
c.v = repmat(k, [1 1 2]).*c.vLOS;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
hold on;
c.v = c.vNLOS;
title('LOS and NLOS separate');
axis([-30 30 1e-3 1]);

figure;
k = 10*randn(N, 1);
c.v = c.vNLOS + repmat(k, [1 1 2]).*c.vLOS;
c.v(:,:,3) = max(c.v, [], 3);
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('LOS+NLOS combined');
axis([-30 30 1e-3 1]);

