% Clear and calculate.
close all;
clear;
drawnow;

% Move around back-and-forth in a square.
d = -40:40;
[xx, yy] = ndgrid(d, d);
xx(:, 2:2:end) = flipud(xx(:, 2:2:end));
nRows = size(xx, 1);
nCols = size(xx, 2);
N = nRows*nCols;

% Antennas.
a1 = read_farfield_wipld('wipld/two_dipoles.ra1');
a1.f = a1.f(1);
a1.D0 = a1.D0(1);
P = integrate_farfield(a1); % normalize
a1.E_theta = a1.E_theta(:,1)*sqrt(4*pi/P); % normalize
a1.E_phi = a1.E_phi(:,1)*sqrt(4*pi/P); % normalize
a2 = rotate_farfield(a1, pi, 0, 0);

% Cluster environment.
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));
nWavesOrClustersVector = [1 2 4 8 16 20];

% Set seed of random generator.
reset(RandStream.getGlobalStream, 0);
for ii = 1:length(nWavesOrClustersVector)
    nWavesOrClusters = nWavesOrClustersVector(ii);
    disp(['Calculating case ' num2str(ii) '...']);
    for jj = 1

        % Isotropic environment.
        iso.a = [a1 a2];
        iso.p = gen_positions([0 0], 0, 0, 0, 0, 0);
        iso.w = gen_waves('3D', nWavesOrClusters, N);

        % Clusters.
        cluster.a = [a1 a2];
        alpha = repmat(2*pi*rand(1, ceil(N/10))-pi, 10, 1);
        theta = repmat(acos(1-2*rand(1, ceil(N/10))), 10, 1);
        phi = repmat(2*pi*rand(1, ceil(N/10))-pi, 10, 1);
        alpha = alpha(1:N);
        theta = theta(1:N);
        phi = phi(1:N);
        cluster.p = gen_positions([xx(:) xx(:)], yy(:), 0, ...
            alpha(:), theta(:), phi(:));
        cluster.c = gen_clusters(20, nWavesOrClusters);

        % Calculate all the parameters.
        cluster_mat(ii, jj) = calc(cluster, nSamplesVector, 1, 2);
        iso_mat(ii, jj) = calc(iso, nSamplesVector, 1, 2);
    end
end

save example25
