% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e4;

% Generate one statistical line-of-sight wave for each realization.
c.w = gen_waves('3D', 1, N);
%%%normFactors = sqrt(abs(c.w.E_theta).^2 + abs(c.w.E_phi).^2);
%%%c.w.E_theta = c.w.E_theta ./ normFactors;
%%%c.w.E_phi = c.w.E_phi ./ normFactors;

% Antennas and positions.
c.a = [gen_farfield('isotropic theta') ...
       gen_farfield('isotropic phi')];
c.p = gen_positions(0, 0, 0, 0, [0 0], 0);
plot_farfield(c.a);
%save_fig([mfilename '_1']);

% Calculate port voltages.
c.v = calc_v(c);
c.v(:,:,3) = max(c.v, [], 3);  % selection combining

% Plot CDF.
figure;
subplot(1, 2, 1);
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('Line-of-sight');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Isotropic theta', 'Isotropic phi', ...
    'Selection combined', 'Location', 'northwest');

% Rich isotropic environment.
c.w = gen_waves('3D', 20, N);
c.v = calc_v(c);
c.v(:,:,3) = max(c.v, [], 3);  % selection combining
subplot(1, 2, 2);
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('Rich Isotropic');
axis([-40 0 1e-3 1e0]);
%save_fig([mfilename '_2']);

% Generate one statistical line-of-sight wave for each realization.
c.w = gen_waves('3D', 1, N);
%%%normFactors = sqrt(abs(c.w.E_theta).^2 + abs(c.w.E_phi).^2);
%%%c.w.E_theta = c.w.E_theta ./ normFactors;
%%%c.w.E_phi = c.w.E_phi ./ normFactors;

% Antennas and positions.
c.a = [gen_farfield('incremental electric dipole') ...
       gen_farfield('incremental electric dipole')];
c.p = gen_positions(0, 0, 0, 0, [0 pi/2], 0);
figure;
plot_farfield(c.a);
%save_fig([mfilename '_3']);

% Calculate port voltages.
c.v = calc_v(c);
c.v(:,:,3) = max(c.v, [], 3);  % selection combining

% Plot CDF.
figure;
subplot(1, 2, 1);
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('Line-of-sight');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Vertical dipole', 'Horizontal dipole', ...
    'Selection combined', 'Location', 'northwest');

% Rich isotropic environment.
c.w = gen_waves('3D', 20, N);
c.v = calc_v(c);
c.v(:,:,3) = max(c.v, [], 3);  % selection combining
subplot(1, 2, 2);
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('Rich Isotropic');
axis([-40 0 1e-3 1e0]);
%save_fig([mfilename '_4']);

% Generate one statistical line-of-sight wave for each realization.
c.w = gen_waves('3D', 1, N);
%%%normFactors = sqrt(abs(c.w.E_theta).^2 + abs(c.w.E_phi).^2);
%%%c.w.E_theta = c.w.E_theta ./ normFactors;
%%%c.w.E_phi = c.w.E_phi ./ normFactors;

% Antennas and positions.
c.a = [gen_farfield('cosn 70') ...
       gen_farfield('cosn 70')];
c.p = gen_positions(0, 0, 0, 0, [0 pi/2], 0);
figure;
plot_farfield(c.a);
%save_fig([mfilename '_5']);

% Calculate port voltages.
c.v = calc_v(c);
c.v(:,:,3) = max(c.v, [], 3);  % selection combining

% Plot CDF.
figure;
subplot(1, 2, 1);
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('Line-of-sight');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Cosn z-directed', 'Cosn y-directed', ...
    'Selection combined', 'Location', 'northwest');

% Rich isotropic environment.
c.w = gen_waves('3D', 20, N);
c.v = calc_v(c);
c.v(:,:,3) = max(c.v, [], 3);  % selection combining
subplot(1, 2, 2);
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('Rich Isotropic');
axis([-40 0 1e-3 1e0]);
%save_fig([mfilename '_6']);
