% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));

% Environment, antennas, positions.
wLOS = gen_waves('3D',  1, N);
normFactor = hypot(abs(wLOS.E_theta), abs(wLOS.E_phi));
wLOS.E_theta = wLOS.E_theta ./ normFactor;
wLOS.E_phi   = wLOS.E_phi   ./ normFactor;
wISO = gen_waves('3D', 20, N);
a = [gen_farfield('incremental Huygens source', 81, 161) ...
     gen_farfield('incremental Huygens source', 81, 161)];
p = gen_positions(0, 0, 0, 0, [-pi/4 pi/4], 0);

% Cases.
cLOS = struct('w', wLOS, 'a', a, 'p', p);
cISO = struct('w', wISO, 'a', a, 'p', p);
figure;
plot_farfield_inpos(cLOS, [], 'interp', 0.5);
%save_fig('ISAP_10b_ANT_Huygens90', 10);

% Calculate port voltages and capacity.
cLOS = calc(cLOS, nSamplesVector, 1, 2, 'linear');
cISO = calc(cISO, nSamplesVector, 1, 2, 'linear');

% Diversity combining.
cLOS.v = cat(3, cLOS.v, diversity('mrc', cLOS.v));
cISO.v = cat(3, cISO.v, diversity('mrc', cISO.v));

% Line-of-sight.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cLOS.v);
title('Random Line-of-sight Environment');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Huygens Source 1', ...
    'Huygens Source 2', 'Maximum Ratio Combined', 'Location', 'northwest');
%save_fig('ISAP_11b_LOS_Huygens90', 10);

% Rich isotropic environment.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cISO.v);
title('Rich Isotropic Environment');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Huygens Source 1', ...
    'Huygens Source 2', 'Maximum Ratio Combined', 'Location', 'northwest');
%save_fig('ISAP_12b_ISO_Huygens90', 10);

%-------------------------------------------------------------------------------
% Capacity

% Ugly hack.
cLOS.capacity(:,2) = cISO.capacity;

figure;
plot_parameter('capacity', cLOS, [], {'Random Line-of-sight Environment', ...
    'Rich Isotropic Environment'});
%save_fig('ISAP_CAP_04b_Huygens90', 10);

fprintf('Mean capacity for one antenna LOS = %f\n', ...
    calc_meancapacity(cLOS.v(:, :, 1)));
fprintf('Mean capacity for one antenna ISO = %f\n', ...
    calc_meancapacity(cISO.v(:, :, 1)));
