% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

pth = '../data/SonyEricsson/';
name = 'SeTalkingLb';

N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));

% Environment, antennas, positions.
wLOS = gen_waves('3D',  1, N);
normFactor = hypot(abs(wLOS.E_theta), abs(wLOS.E_phi));
wLOS.E_theta = wLOS.E_theta ./ normFactor;
wLOS.E_phi   = wLOS.E_phi   ./ normFactor;
wISO = gen_waves('3D', 20, N);
a = [read_farfield_sonyericsson([pth name '1.txt']) ...
     read_farfield_sonyericsson([pth name '2.txt'])];
a(1) = set_power_radiated(a(1));
a(2) = set_power_radiated(a(2));
p = gen_positions(0, 0, 0, 0, [0 0], 0);

% Cases.
cLOS = struct('w', wLOS, 'a', a, 'p', p);
cISO = struct('w', wISO, 'a', a, 'p', p);
figure;
plot_farfield_inpos(cLOS, [], 'interp', 1);
%save_fig(['ISAP_19_ANT_' name], 10);

% Calculate port voltages and capacity.
cLOS = calc(cLOS, nSamplesVector, 1, 2, 'linear');
cISO = calc(cISO, nSamplesVector, 1, 2, 'linear');

% Diversity combining.
cLOS.v = cat(3, cLOS.v, diversity('mrc', cLOS.v));
cISO.v = cat(3, cISO.v, diversity('mrc', cISO.v));

% Line-of-sight.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cLOS.v);
title('Random Line-of-sight Environment');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', [name ' 1'], [name ' 2'], ...
    'Maximum Ratio Combined', 'Location', 'northwest');
%save_fig(['ISAP_20_LOS_' name], 10);

% Rich isotropic environment.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cISO.v);
title('Rich Isotropic Environment');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', [name ' 1'], [name ' 2'], ...
    'Maximum Ratio Combined', 'Location', 'northwest');
%save_fig(['ISAP_21_ISO_' name], 10);
