% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));

% Environment, antennas, positions.
wLOS = gen_waves('3D', 1, N);
normFactor = hypot(abs(wLOS.E_theta), abs(wLOS.E_phi));
wLOS.E_theta = wLOS.E_theta ./ normFactor;
wLOS.E_phi   = wLOS.E_phi   ./ normFactor;
wISO = gen_waves('3D', 20, N);
a = [gen_farfield('incremental electric dipole', 81, 161) ...
     gen_farfield('incremental electric dipole', 81, 161)];
p = gen_positions([-0.2 0.2], 0, 0, 0, 0, 0);

% Cases.
cLOS = struct('w', wLOS, 'a', a, 'p', p);
cISO = struct('w', wISO, 'a', a, 'p', p);
figure;
plot_farfield_inpos(cLOS);
%save_fig('Antennas_eedip', 10);

% Calculate port voltages.
cLOS.v = calc_v(cLOS, 'linear');
cISO.v = calc_v(cISO, 'linear');

% Combine antenna ports.
c.LOS.v = combine_antenna_ports(cLOS.v, [+1 +1 ; +1 -1]);
c.ISO.v = combine_antenna_ports(cISO.v, [+1 +1 ; +1 -1]);

% Calculate capacity.
cLOS = calc(cLOS, nSamplesVector, 1, 2);
cISO = calc(cISO, nSamplesVector, 1, 2);

% Diversity combining.
cLOS.v = cat(3, cLOS.v, diversity('mrc', cLOS.v));
cISO.v = cat(3, cISO.v, diversity('mrc', cISO.v));

% Line-of-sight.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cLOS.v);
title('Random Line-of-sight Environment');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Electric Dipole 1', ...
    'Electric Dipole 2', 'Maximum Ratio Combined', 'Location', 'northwest');

% Rich isotropic environment.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cISO.v);
title('Rich Isotropic Environment');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Electric Dipole 1', ...
    'Electric Dipole 2', 'Maximum Ratio Combined', 'Location', 'northwest');

%-------------------------------------------------------------------------------
% Capacity

% Ugly hack.
cLOS.capacity(:,2) = cISO.capacity;

figure;
plot_parameter('capacity', cLOS, [], {'Random Line-of-sight Environment', ...
    'Rich Isotropic Environment'});

fprintf('Mean capacity for one antenna LOS = %f\n', ...
    calc_meancapacity(cLOS.v(:, :, 1)));
fprintf('Mean capacity for one antenna ISO = %f\n', ...
    calc_meancapacity(cISO.v(:, :, 1)));
