% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

% Grid of positions.
[xx1, yy1] = gen_grid('rectangular', 0.05, 301);
xx2 = xx1(1:10:end, 1:10:end);  % sparser grid
yy2 = yy1(1:10:end, 1:10:end);  % sparser grid

% Define 2 cases.
case1.w = gen_waves('3D', 20, 1, 'Linear');
case1.p = gen_positions(xx1(:), yy1(:), 0, 0, 0, 0);
case1.a = gen_farfield('incremental electric dipole');
case2.w = case1.w;
case2.p = gen_positions(xx2(:), yy2(:), 0, 0, [0 pi/2], 0);
case2.a = [gen_farfield('incremental electric dipole') ...
           gen_farfield('incremental electric dipole')];

% Calculate voltage at port.
case1.v = calc_v(case1);
case2.v = calc_v(case2);

% Diversity.
case2.v = cat(3, case2.v, diversity('mrc', case2.v));

% Plot field.
A1 = reshape(abs(case1.v), size(xx1));
A1 = A1 / max(A1(:));

figure('OuterPosition', figpos('big'));
surf(xx1, yy1, A1);
shading(gca, 'interp');
plot_waves(case1.w);
zz2 = zeros(numel(xx2), 1);
plot3([xx2(:) xx2(:)]', [yy2(:) yy2(:)]', [zz2+0.5 zz2+0.7]', 'k-');
%save_fig([mfilename '_1_field'], 32, [], 200);

% Plot
A2_nodiv = reshape(abs(case2.v(:, :, 1)), size(xx2));
A2_nodiv_bins = calc_bins(20*log10(A2_nodiv), [-20 -10])/2;

figure;
surf(xx2, yy2, zeros(size(xx2)), A2_nodiv_bins);
title('Rich Isotropic Environment');
colormap(gray);
caxis([0 1]);
view(0, 90);
axis image;
grid off;
box off;
%save_fig([mfilename '_2_ver'], 32, [], 200);

% Plot
A2_nodiv = reshape(abs(case2.v(:, :, 2)), size(xx2));
A2_nodiv_bins = calc_bins(20*log10(A2_nodiv), [-20 -10])/2;

figure;
surf(xx2, yy2, zeros(size(xx2)), A2_nodiv_bins);
title('Rich Isotropic Environment');
colormap(gray);
caxis([0 1]);
view(0, 90);
axis image;
grid off;
box off;
%save_fig([mfilename '_3_hor'], 32, [], 200);

% Plot
A2_div = reshape(abs(case2.v(:, :, 3)), size(xx2));
A2_div_bins = calc_bins(20*log10(A2_div), [-20 -10])/2;

figure;
surf(xx2, yy2, zeros(size(xx2)), A2_div_bins);
title('Rich Isotropic Environment');
colormap(gray);
caxis([0 1]);
view(0, 90);
axis image;
grid off;
box off;
%save_fig([mfilename '_4_div'], 32, [], 200);

figure;
case2.v = squeeze(case2.v);
plot_cdf_rayleigh(); hold on;
plot_cdf(case2.v);
plot_cdf_format();
title('Rich Isotropic Environment');
legend('Rayleigh', 'Vertical dipole', 'Horizontal dipole', ...
    'Diversity (MRC)', 'Location', 'southeast');
%save_fig([mfilename '_5_cdf'], 10);
