% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

% Grid of positions.
[xx, yy] = gen_grid('rectangular', 0.5, 31);

% Define 2 cases.
w = gen_waves('3D', 1, numel(xx), 'Linear');
normFactor = hypot(w.E_theta, w.E_phi);
w.E_theta = w.E_theta ./ normFactor;
w.E_phi   = w.E_phi   ./ normFactor;
case1.w = w;
case1.p = gen_positions(xx(:), yy(:), 0, 0, [0 pi/2], 0);
case1.a = [gen_farfield('incremental electric dipole') ...
           gen_farfield('incremental electric dipole')];

% Calculate voltage at port.
case1.v = calc_v(case1);
case1.v = cat(3, diag(case1.v(:, :, 1)), diag(case1.v(:, :, 2)));

% Diversity.
case1.v = cat(3, case1.v, diversity('mrc', case1.v));

% Plot
A_ver = reshape(abs(case1.v(:, :, 1)), size(xx));
A_ver_bins = calc_bins(20*log10(A_ver), [-20 -10])/2;

cmap = jet(256);
cmap(end,:) = 1;

figure;
surf(xx, yy, zeros(size(xx)), A_ver_bins);
title('Random Line-of-sight Environment');
colormap(cmap);
caxis([0 1]);
view(0, 90);
axis image;
grid off;
box off;
%save_fig([mfilename '_1_ver'], 32, [], 200);

% Plot
A_hor = reshape(abs(case1.v(:, :, 2)), size(xx));
A_hor_bins = calc_bins(20*log10(A_hor), [-20 -10])/2;

figure;
surf(xx, yy, zeros(size(xx)), A_hor_bins);
title('Random Line-of-sight Environment');
colormap(cmap);
caxis([0 1]);
view(0, 90);
axis image;
grid off;
box off;
%save_fig([mfilename '_2_hor'], 32, [], 200);

% Plot
A_div = reshape(abs(case1.v(:, :, 3)), size(xx));
A_div_bins = calc_bins(20*log10(A_div), [-20 -10])/2;

figure;
surf(xx, yy, zeros(size(xx)), A_div_bins);
title('Random Line-of-sight Environment');
colormap(cmap);
caxis([0 1]);
view(0, 90);
axis image;
grid off;
box off;
%save_fig([mfilename '_3_div'], 32, [], 200);

figure;
case1.v = squeeze(case1.v);
plot_cdf_rayleigh(); hold on;
plot_cdf(case1.v);
plot_cdf_format();
title('Random Line-of-sight Environment');
legend('Rayleigh', 'Vertical dipole', 'Horizontal dipole', ...
    'Diversity (MRC)', 'Location', 'southeast');
%save_fig([mfilename '_4_cdf'], 10);
