close all;
clear;

% First antenna.
a1 = read_farfield_bluetest('Bluetest/test.txt');

% Second antenna.
a2 = rotate_farfield(a1, pi/4, 0, 0);

% Plot far-field of antennas.
%figure;
%plot_farfield(a1, [], 'interp');
%figure;
%plot_farfield(a2, [], 'interp');

% Compute the correlation from far-fields.
corr_farfields = farfield_correlation(a1, a2);
disp(['Correlation from far-field integrations = ' num2str(corr_farfields)]);

% Generate an isotropic rich multipath environment.
N = 10000;
case1.w = gen_waves('3D', 20, N);

% Place the antennas in origin.
case1.p = gen_positions([0 0], 0, 0, 0, 0, 0);
case1.a = [a1 a2];

% Calculate a lot of stuff for this case.
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));
case1 = calc(case1, nSamplesVector, 1, 2);
corr_samples = case1.correlation(:, 1, 1, 2);
disp(['Correlation from samples in rich mult-path = ' ...
    num2str(corr_samples(end))]);

% Plot convergence of correlation from increasing number of samples and compare
% with far-field integration.
figure;
semilogx(nSamplesVector, abs(corr_samples), 'b-', ...
    [10 N], abs(corr_farfields)*[1 1], 'r-', 'linewidth', 1);
title('Correlation');
xlabel('Number of samples [-]');
ylabel('Correlation [-]');
axis([10 N 0 1]);
legend('From samples in rich multi-path', 'From far-field integration', ...
    'Location', 'southwest');
