% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));

% LOS elliptical polarized.
wLOS_ell = gen_waves('3D', 1, N);
normFactor = hypot(wLOS_ell.E_theta, wLOS_ell.E_phi);
wLOS_ell.E_theta = wLOS_ell.E_theta ./ normFactor;
wLOS_ell.E_phi   = wLOS_ell.E_phi   ./ normFactor;

% LOS linear polarized.
wLOS_lin = wLOS_ell;
phase = 2*pi*rand(1, N);
psi = 2*pi*rand(1, N);
wLOS_lin.E_theta = cos(psi) .* exp(1j*phase);
wLOS_lin.E_phi   = sin(psi) .* exp(1j*phase);

% LOS circular polarized.
wLOS_cir = wLOS_ell;
wLOS_cir.E_theta = sqrt(0.5)*exp(1j*phase);
wLOS_cir.E_phi   = sqrt(0.5)*exp(1j*(phase+pi/2));

% Antennas and positions.
a = [gen_farfield('incremental electric dipole', 81, 161) ...
     gen_farfield('incremental electric dipole', 81, 161)];
p = gen_positions(0, 0, 0, 0, [0 pi/2], 0);

% Cases.
cLOS_ell = struct('w', wLOS_ell, 'a', a, 'p', p);
cLOS_lin = struct('w', wLOS_lin, 'a', a, 'p', p);
cLOS_cir = struct('w', wLOS_cir, 'a', a, 'p', p);

% Plot waves.
figure;
for ii = 1:40
    plot_waves(cLOS_ell.w, ii);
    hold on;
end
%save_fig([mfilename '_w_elliptical'], 10);

figure;
for ii = 1:40
    plot_waves(cLOS_lin.w, ii);
    hold on;
end
%save_fig([mfilename '_w_linear'], 10);

figure;
for ii = 1:40
    plot_waves(cLOS_cir.w, ii);
    hold on;
end
%save_fig([mfilename '_w_circular'], 10);

figure;
plot_farfield_inpos(cLOS_lin, [], 'interp', 2.5);

% Calculate port voltages and capacity.
cLOS_ell = calc(cLOS_ell, nSamplesVector, 1, 2, 'spline');
cLOS_lin = calc(cLOS_lin, nSamplesVector, 1, 2, 'spline');
cLOS_cir = calc(cLOS_cir, nSamplesVector, 1, 2, 'spline');

% Diversity combining.
cLOS_ell.v = cat(3, cLOS_ell.v, diversity('mrc', cLOS_ell.v));
cLOS_lin.v = cat(3, cLOS_lin.v, diversity('mrc', cLOS_lin.v));
cLOS_cir.v = cat(3, cLOS_cir.v, diversity('mrc', cLOS_cir.v));

% Line-of-sight.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cLOS_ell.v);
title('LOS Elliptical');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Electric Dipole 1', ...
    'Electric Dipole 2', 'Maximum Ratio Combined', 'Location', 'northwest');
%save_fig([mfilename '_elliptical'], 10);

% Line-of-sight.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cLOS_lin.v);
title('LOS Linear');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Electric Dipole 1', ...
    'Electric Dipole 2', 'Maximum Ratio Combined', 'Location', 'northwest');
%save_fig([mfilename '_linear'], 10);

% Line-of-sight.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(cLOS_cir.v);
title('LOS Circular');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Electric Dipole 1', ...
    'Electric Dipole 2', 'Maximum Ratio Combined', 'Location', 'northwest');
%save_fig([mfilename '_circular'], 10);
