% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));

pth = '../data/SonyEricsson/';
filenames = {'SeFreeSpaceHb1.txt', 'SeFreeSpaceHb2.txt', ...
             'SeFreeSpaceLb1.txt', 'SeFreeSpaceLb2.txt', ...
             'SeTalkingHb1.txt'  , 'SeTalkingHb2.txt'  , ...
             'SeTalkingLb1.txt'  , 'SeTalkingLb2.txt'    };

for ii = 1:length(filenames)

    file_tx = filenames{ii};
    file_rx = filenames{ii};

    % Two SE antennas, normalized.
    a1 = read_farfield_sonyericsson([pth file_tx]);
    a2 = read_farfield_sonyericsson([pth file_rx]);
    a1 = set_power_radiated(a1);
    a2 = set_power_radiated(a2);

    % Transmit/receive in (isotropic) random directions.
    theta = acos(1-2*rand(N, 2));
    phi = 2*pi*rand(N, 2);

    % Transmitted/received waves from antenna 1 and 2 respectively.
    Eth_tx = interp2_safe(a1.phi, a1.theta, a1.Eth, phi(:,1), theta(:,1));
    Eph_tx = interp2_safe(a1.phi, a1.theta, a1.Eph, phi(:,1), theta(:,1));
    Eth_rx = interp2_safe(a2.phi, a2.theta, a2.Eth, phi(:,2), theta(:,2));
    Eph_rx = interp2_safe(a2.phi, a2.theta, a2.Eph, phi(:,2), theta(:,2));

    % Introduce random relative polarization between transmit and received
    % waves.
    psi = 2*pi*rand(N, 1) - pi;
    Eth_tx_rot = cos(psi).*Eth_tx - sin(psi).*Eph_tx;
    Eph_tx_rot = sin(psi).*Eth_tx + cos(psi).*Eph_tx;

    % Introduce random phase shift between antennas.
    phase = 2*pi*rand(N, 1) - pi;
    Eth_tx_rot = Eth_tx_rot .* exp(1j*phase);
    Eph_tx_rot = Eph_tx_rot .* exp(1j*phase);

    % Calculate coupling with dot product.
    c.v(:,ii) = Eth_tx_rot.*Eth_rx + Eph_tx_rot.*Eph_rx;
    lgnd{ii+1} = [file_tx '->' file_rx]; %#ok<SAGROW>
end

% Plot.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('LOS between two SE antennas (normalized) with random orientations');
axis([-40 0 1e-3 1e0]);
lgnd{1} = 'Theoretical Rayleigh';
legend(lgnd, 'Location', 'northwest');
%save_fig(mfilename, 16);
