% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));

% Combine two orthogonal dipoles (where one has a 90 deg phase shift) to a
% circular polarized antenna.
a1_part1 = gen_farfield('incremental electric dipole', 81, 161);
a1_part2 = rotate_farfield(a1_part1, 0, pi/2, 0);
a1_part2.Eth = a1_part2.Eth * exp(1j*pi/2);
a1_part2.Eph = a1_part2.Eph * exp(1j*pi/2);
a1 = set_power_radiated(merge_farfields(a1_part1, a1_part2));
a2 = gen_farfield('incremental electric dipole', 81, 161);

% Transmit/receive in (isotropic) random directions.
theta = acos(1-2*rand(N, 2));
phi = 2*pi*rand(N, 2) - pi;

% Transmitted/received waves from antenna 1 and 2 respectively.
Eth_tx = interp2_safe(a1.phi, a1.theta, a1.Eth, phi(:,1), theta(:,1));
Eph_tx = interp2_safe(a1.phi, a1.theta, a1.Eph, phi(:,1), theta(:,1));
Eth_rx = interp2_safe(a2.phi, a2.theta, a2.Eth, phi(:,2), theta(:,2));
Eph_rx = interp2_safe(a2.phi, a2.theta, a2.Eph, phi(:,2), theta(:,2));

% Introduce random relative polarization between transmit and received waves.
psi = 2*pi*rand(N, 1) - pi;
Eth_tx_rot = cos(psi).*Eth_tx - sin(psi).*Eph_tx;
Eph_tx_rot = sin(psi).*Eth_tx + cos(psi).*Eph_tx;

% Introduce random phase shift between antennas.
phase = 2*pi*rand(N, 1) - pi;
Eth_tx_rot = Eth_tx_rot .* exp(1j*phase);
Eph_tx_rot = Eph_tx_rot .* exp(1j*phase);

% Calculate coupling with dot product.
c.v = Eth_tx_rot.*Eth_rx + Eph_tx_rot.*Eph_rx;

% Plot.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
title('LOS between circular and linear dipoles with random orientations');
axis([-40 0 1e-3 1e0]);
legend('Theoretical Rayleigh', 'Dipoles(circ)->Dipole', 'Location', 'northwest');
%save_fig(mfilename, 12);
