% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));

cell_matrix_cases = {...
    'LOS Linear'             ,  1, 'Linear'       ; ...
    'LOS Circular'           ,  1, 'CircularRight'; ...
    'LOS Elliptical'         ,  1, 'Elliptical'   ; ...
    'Rich Isotropic Linear'  , 20, 'Linear'       ; ...
    'Rich Isotropic Circular', 20, 'CircularRight'  };

% Antennas and positions.
a = [gen_farfield('incremental electric dipole', 81, 161) ...
     gen_farfield('incremental electric dipole', 81, 161)];
p = gen_positions(0, 0, 0, 0, [0 pi/2], 0);

for ii = 1:size(cell_matrix_cases, 1)

    w = gen_waves('3D', cell_matrix_cases{ii,2}, N, cell_matrix_cases{ii,3});

    % Cases.
    c{ii} = struct('w', w, 'a', a, 'p', p);

    if ii==1
        figure;
        plot_farfield_inpos(c{ii});
        %save_fig([mfilename ' Antennas'], 10);
    end

    % Calculate port voltages.
    c{ii} = calc(c{ii}, nSamplesVector, 1, 2, 'linear');

    % Diversity combining.
    c{ii}.v = cat(3, c{ii}.v, diversity('mrc', c{ii}.v));

    % Plot.
    figure;
    plot_cdf_rayleigh();
    plot_cdf_format();
    plot_cdf(c{ii}.v);
    title(cell_matrix_cases{ii,1});
    axis([-40 0 1e-3 1e0]);
    legend('Theoretical Rayleigh', a(1).name, a(2).name, ...
        'Maximum Ratio Combined', 'Location', 'northwest');
    %save_fig([mfilename ' ' cell_matrix_cases{ii,1}], 10);
end
