% Clear and calculate.
close all;
clear;
drawnow;
reset(RandStream.getGlobalStream, 0);

N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));

cell_matrix_cases = {...
    'LOS Linear'             ,  1, 'Linear'       , 'g' ; ...
    'LOS Circular'           ,  1, 'CircularRight', 'b' ; ...
    'LOS Elliptical'         ,  1, 'Elliptical'   , 'y' ; ...
    'Rich Isotropic Linear'  , 20, 'Linear'       , 'm'   };

% Antennas and positions.
pth = '../data/SonyEricsson/';
tmp = normalize_power_radiated_2best(...
    {read_farfield_sonyericsson([pth 'SeTalkingHb1.txt']), ...
     read_farfield_sonyericsson([pth 'SeTalkingHb2.txt'])});
a = [tmp{1} tmp{2}];
a(1).name = 'Port 1';
a(2).name = 'Port 2';
p = gen_positions(0, 0, 0, 0, [-pi/2 pi/2], 0);

%ppt = ppt_create();
%s = ppt_append_slide(ppt, 'SeTalkingHb');

for ii = 1:size(cell_matrix_cases, 1)

    w = gen_waves('3D', cell_matrix_cases{ii,2}, N, cell_matrix_cases{ii,3});

    % Cases.
    c{ii} = struct('w', w, 'a', a, 'p', p);

    % Calculate port voltages.
    c{ii} = calc(c{ii}, nSamplesVector, 1, 2, 'linear');

    % Diversity combining.
    v_div = diversity('MRC', c{ii}.v);

    % Plot.
    h = figure;
    plot_cdf_rayleigh();
    plot_cdf_format();
    plot_cdf(c{ii}.v(:,:,1), [cell_matrix_cases{ii,4} '-'], 'Port1', 'dBR');
    plot_cdf(c{ii}.v(:,:,2), [cell_matrix_cases{ii,4} '-'], 'Port2', 'dBR');
    plot_cdf_rayleigh(0.5, 'MRC', 2);
    plot_cdf(v_div, [cell_matrix_cases{ii,4} '--'], 'MRC', 'dBR');
    title(cell_matrix_cases{ii,1});
    legend('Rayleigh', a(1).name, a(2).name, 'Location', 'southeast');
    %save_fig('', 11);
    ud = get(h, 'UserData');
    %ppt_add_image(s, ii);
    %ppt_add_textbox(s, join([ud.id;ud.one_percent_level], sprintf('\n')), ii);
end
