close all;
clear;

% Read data files.
pth = '../data/SonyEricsson/';
a{1} = read_farfield_sg64([pth 'Laird_top_antenna_freespace.txt']);
a{1} = set_power_radiated(a{1});
a{1}.shortname = 'fs1';
a{2} = read_farfield_sg64([pth 'Laird_bottom_antenna_freespace.txt']);
a{2} = set_power_radiated(a{2});
a{2}.shortname = 'fs2';
a{3} = read_farfield_sg64([pth 'Laird_top_antenna_single_hand.txt']);
a{3} = set_power_radiated(a{3});
a{3}.shortname = 'sh1';
a{4} = read_farfield_sg64([pth 'Laird_bottom_antenna_single_hand.txt']);
a{4} = set_power_radiated(a{4});
a{4}.shortname = 'sh2';

% Define case (with several frequencies).
N = 1e5;
nSamplesVector = unique(round(logspace(log10(10), log10(N), 1000)));
w = gen_waves('3D', 1, N, 'Linear');
p = gen_positions([0 0 0 0], 0, 0, 0, 0, 0);
c = struct('w', w, 'a', [a{1} a{2} a{3} a{4}], 'p', p);

% Calculate port voltages.
c.v = calc_v(c);
v_sort = sort(c.v, 1, 'ascend');
indx_one_percent = round(0.01*size(v_sort, 1));
p_dB_one_percent = 20*log10(abs(v_sort(indx_one_percent, :, :, :)));

for iAnt = 1:numel(a)
    name_start = [mfilename '_' a{iAnt}.shortname '_'];
    figure;
    for iFreq = numel(a{iAnt}.f)
        freq_str = num2str(a{iAnt}.f(iFreq)/1e6, '%04d');
        text_str = [a{iAnt}.shortname ', ' freq_str ' MHz, ' ...
            num2str(p_dB_one_percent(1, 1, iAnt, iFreq),'%.1f') ' dB (CDF1%)'];
        plot_farfield(a{iAnt}, [], 'interp', [], iFreq);
        text(0, 0.1, text_str, 'FontSize', 10, 'Units', 'normalized');
        %save_fig([name_start freq_str 'MHz.png'], 6, [], 400);
    end
end
