close all;
clear;

% Generate a cell array of antennas.
a{1} = gen_farfield('incremental electric dipole');  % z-directed
a{1} = rotate_farfield(a{1}, 0, pi/4,    0);  % in xz-plane
a{2} = rotate_farfield(a{1}, 0, pi/2,    0);  % in xz-plane
a{3} = rotate_farfield(a{1}, 0, pi/4, pi/2);  % y-directed
nant = numel(a);

% Plot far-fields.
figure;
for iant = 1:nant
    plot_farfield(a{iant});
    hold on;
end

% Calculate random LOS with regular sampling.
[v_lin, v_rhc, ~] = calc_rlos(a, 10000);

% Plot CDF of theoretical Rayleigh.
h = figure;
plot_cdf_rayleigh();
plot_cdf_format();

% Plot CDF of antennas.
p1styles = {'g-', 'g--', 'g--'};
p2styles = {'b-', 'b--', 'b--'};
for iant = 1:nant
    v1 = diversity('mrc', v_lin(:,:,1:iant));
    v2 = diversity('mrc', v_rhc(:,:,1:iant));
    plot_cdf(v1(:), p1styles{iant}, 'LP', 'dBR');
    plot_cdf(v2(:), p2styles{iant}, 'CP', 'dBR');
end
plot_cdf(0.98*v1(:), p1styles{3});  % Tweak: Shift overlapped curve.
plot_cdf_rayleigh(0.5, 'MRC', 2);
legend('Rayleigh', 'LP', 'CP', 'Location', 'southeast');
