close all;
clear;

% Generate a cell array of antennas.
a_tmp = gen_farfield('incremental Huygens source', 101);
a{1} = rotate_farfield(a_tmp,    0,  0, 0);
a{2} = rotate_farfield(a_tmp, pi/2,  0, 0);
a{3} = rotate_farfield(a_tmp, pi/2, pi, 0);
nant = numel(a);

% Plot far-fields.
for ii = 1:nant, figure; plot_farfield(a{ii}); end

% Calculate random LOS with regular sampling.
[v_lin, v_rhc, ~] = calc_rlos(a, 1e5);

% Plot CDF of thoretical Rayleigh.
h = figure;
plot_cdf_rayleigh();
plot_cdf_format();

% Plot CDF of antennas.
antCombCell = {1, [1 2], [1 3]};
names = {'One Huygens', 'Two Huygens Same Dir., Orthogonal Pol.', ...
    'Two Huygens Opposite Dir., Orthogonal Pol.'};
p1styles = {'g-', 'g--'};
p2styles = {'b-', 'b--'};
for ii = 1:numel(antCombCell)
    n = numel(antCombCell{ii});
    v1 = diversity('mrc', v_lin(:,:,antCombCell{ii}));
    v2 = diversity('mrc', v_rhc(:,:,antCombCell{ii}));
    if ii==2, v2 = 0.98*v2; end  % Tweak: Avoid overlap.
    plot_cdf(v1(:), p1styles{(n>1)+1}, 'LP', 'dBR');
    plot_cdf(v2(:), p2styles{(n>1)+1}, 'CP', 'dBR');
end
plot_cdf_rayleigh([], 'MRC', 2);
legend('Rayleigh', 'LP', 'CP', 'Location', 'southeast');
title('Huygens Sources');
