close all;
clear;

fname1 = '../data/SonyEricsson/Laird_top_antenna_freespace.txt';
fname2 = '../data/SonyEricsson/Laird_bottom_antenna_freespace.txt';
fname3 = '../data/SonyEricsson/Laird_top_antenna_single_hand.txt';
fname4 = '../data/SonyEricsson/Laird_bottom_antenna_single_hand.txt';
cases = {[] , 1e9, fname1, fname2, 'Low Band, Free-Space'  ; ...
         1e9, [] , fname1, fname2, 'High Band, Free-Space' ; ...
         [] , 1e9, fname3, fname4, 'Low Band, Hand Held'   ; ...
         1e9, [] , fname3, fname4, 'High Band, Hand Held'    };

for ii = 1:size(cases,1)

    % Read data files and normalize.
    a = normalize_power_radiated_2best({...
        read_farfield_sg64(cases{ii,3}, cases{ii,1}, cases{ii,2}), ...
        read_farfield_sg64(cases{ii,4}, cases{ii,1}, cases{ii,2})});
    
    % Plot CDF curves for all frequencies.
    figure;
    plot_cdf_rayleigh(0.5, 'MRC', 2);
    plot_cdf_format();
    title(cases{ii,5});
    for ifreq = 1:numel(a{1}.f)
        [v_lin, v_rhc, v_lhc] = calc_rlos(a, 1e5, ifreq);
        v_lin_div = diversity('MRC', v_lin);
        v_rhc_div = diversity('MRC', v_rhc);
        v_lhc_div = diversity('MRC', v_lhc);
        plot_cdf(v_lin_div(:), 'g--');
        plot_cdf(v_rhc_div(:), 'b--');
        plot_cdf(v_lhc_div(:), 'r--');
    end
    plot_cdf_rayleigh(0.5, 'MRC', 2);  % again to be on top
    legend('Rayleigh', 'LP', 'RHCP', 'LHCP', 'Location', 'southeast');
    drawnow;
end
