close all;
clear;

fname1 = '../data/SonyEricsson/Laird_top_antenna_freespace.txt';
fname2 = '../data/SonyEricsson/Laird_bottom_antenna_freespace.txt';
fname3 = '../data/SonyEricsson/Laird_top_antenna_single_hand.txt';
fname4 = '../data/SonyEricsson/Laird_bottom_antenna_single_hand.txt';
cases = {[] , 1e9, fname1, fname2, 'Low Band, Free-Space'  ; ...
         1e9, [] , fname1, fname2, 'High Band, Free-Space' ; ...
         [] , 1e9, fname3, fname4, 'Low Band, Hand Held'   ; ...
         1e9, [] , fname3, fname4, 'High Band, Hand Held'    };

% Define default line widths for plots later.
set(0, 'DefaultLineLineWidth', 1);

% From text output of "example58_cdf_farfield_3dipMRC.m" we get:
dipoles_lin_dBR = [-14.8  7.1];
dipoles_rhc_dBR = [  4.8 21.7];

% From text output of "example59_cdf_farfield_Huygens.m" we get:
huygens_lin_dBR = [-26.2 -12.4  2.8];
huygens_rhc_dBR = [-15.4 -12.4 21.7];

for ii = 1:size(cases,1)

    % Read data files and normalize.
    a = normalize_power_radiated_2best({...
        read_farfield_sg64(cases{ii,3}, cases{ii,1}, cases{ii,2}), ...
        read_farfield_sg64(cases{ii,4}, cases{ii,1}, cases{ii,2})});

    % Calculate deviation from Rayleigh for CDF curves for all frequencies.
    nfreq = numel(a{1}.f);
    dev_lin_dBR = zeros(nfreq,3);
    dev_rhc_dBR = zeros(nfreq,3);
    dev_lhc_dBR = zeros(nfreq,3);
    for ifreq = 1:nfreq
        [v_lin, v_rhc, v_lhc] = calc_rlos(a, 1e5, ifreq);
        v_lin(:,:,3) = diversity('MRC', v_lin);
        v_rhc(:,:,3) = diversity('MRC', v_rhc);
        v_lhc(:,:,3) = diversity('MRC', v_lhc);
        dev_lin_dBR(ifreq,:) = get_cdf_level(squeeze(v_lin), 'dBR');
        dev_rhc_dBR(ifreq,:) = get_cdf_level(squeeze(v_rhc), 'dBR');
        dev_lhc_dBR(ifreq,:) = get_cdf_level(squeeze(v_lhc), 'dBR');
        fprintf('Calculated case %d, frequency %d.\n', ii, ifreq);
    end
    disp('lin'); min(dev_lin_dBR,[],1),  max(dev_lin_dBR,[],1)
    disp('rhc'); min(dev_rhc_dBR,[],1),  max(dev_rhc_dBR,[],1)
    disp('lhc'); min(dev_lhc_dBR,[],1),  max(dev_lhc_dBR,[],1)

    figure;
    plot(a{1}.f/1e6, dev_lin_dBR(:,1), 'go-' ); hold on;
    plot(a{1}.f/1e6, dev_rhc_dBR(:,1), 'bo-' );
    plot(a{1}.f/1e6, dev_lhc_dBR(:,1), 'ro-' );
    plot(a{1}.f/1e6, dev_lin_dBR(:,2), 'go-' );
    plot(a{1}.f/1e6, dev_rhc_dBR(:,2), 'bo-' );
    plot(a{1}.f/1e6, dev_lhc_dBR(:,2), 'ro-' );
    plot(a{1}.f/1e6, dev_lin_dBR(:,3), 'go--');
    plot(a{1}.f/1e6, dev_rhc_dBR(:,3), 'bo--');
    plot(a{1}.f/1e6, dev_lhc_dBR(:,3), 'ro--');
    axis([min(a{1}.f/1e6) max(a{1}.f/1e6) -10 20]);
    grid on;
    title(cases{ii,5});
    xlabel('Frequency [MHz]');
    ylabel('Level at 1% CDF [dBR]');
    legend('LP', 'RHCP', 'LHCP', 'Location', 'southeast');

    plot([700 3000], [1;1]*dipoles_lin_dBR, 'g-' );
    plot([700 3000], [1;1]*dipoles_rhc_dBR, 'b-' );
    plot([700 3000], [1;1]*huygens_lin_dBR, 'g--');
    plot([700 3000], [1;1]*huygens_rhc_dBR, 'b--');
    axis([min(a{1}.f/1e6) max(a{1}.f/1e6) -20 30]);
    drawnow;
end
