close all;
clear;

c.w = gen_waves('3D', 20, 1e5, 'Linear');

pth = '../data/SonyEricsson/Laird_';
a{1} = read_farfield_sg64([pth 'top_antenna_freespace.txt'     ], 2.2e9);
a{2} = read_farfield_sg64([pth 'bottom_antenna_freespace.txt'  ], 2.2e9);
a{3} = read_farfield_sg64([pth 'top_antenna_single_hand.txt'   ], 2.2e9);
a{4} = read_farfield_sg64([pth 'bottom_antenna_single_hand.txt'], 2.2e9);
a(1:2) = normalize_power_radiated_2best(a(1:2));
a(3:4) = normalize_power_radiated_2best(a(3:4));
nant = numel(a);

c.a = [a{1} a{2} a{3} a{4}];
c.p = gen_positions([0 0 0 0],0,0,0,0,0);
v_iso = sqrt(2)*calc_v(c);

% Plot CDF curves for all frequencies.
h = figure;
plot_cdf_rayleigh(1);
plot_cdf_format();
ifreq = 1;
[v_lin, ~, ~] = calc_rlos(a, 1e5, ifreq);
v_lin = sqrt(2)*v_lin;
for iant = 3:nant %%%
    v_los_tmp = v_lin(:,:,iant);
    v_iso_tmp = v_iso(:,:,iant,ifreq);
    plot_cdf(v_los_tmp(:), 'g-', 'LP LOS', 'dBR1');
    plot_cdf(v_iso_tmp(:), 'r-', 'RIMP', 'dBR1');
    p_los_dBR = get_cdf_level(v_los_tmp(:),'dBR1');
    p_iso_dBR = get_cdf_level(v_iso_tmp(:),'dBR1');
    fprintf('Random LOS, antenna %d, %5.1f dBR\n', iant, p_los_dBR);
    fprintf('RIMP, antenna %d, %5.1f dBR\n', iant, p_iso_dBR);
end
plot_cdf_rayleigh(1, 'MRC', 2);
for idiv = 3 %%%
    v_los_div = diversity('MRC', v_lin(:,:,idiv:idiv+1));
    plot_cdf(v_los_div(:), 'g--', 'LP LOS', 'dBR1');
    v_iso_div = diversity('MRC', v_iso(:,:,idiv:idiv+1,:));
    plot_cdf(v_iso_div(:), 'r--', 'RIMP', 'dBR1');
    p_los_dBR = get_cdf_level(v_los_div(:),'dBR1');
    p_iso_dBR = get_cdf_level(v_iso_div(:),'dBR1');
    fprintf('Random LOS diversity, antenna %d-%d, %5.1f dBR\n', idiv, idiv+1, p_los_dBR);
    fprintf('RIMP diversity, antenna %d-%d, %5.1f dBR\n', idiv, idiv+1, p_iso_dBR);
end
plot_cdf_rayleigh(1);
legend('Rayleigh', '3D RLOS', 'RIMP', 'Location', 'southeast');

return; %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Plot CDF curves for all frequencies.
for ifreq = 2:numel(a{1}.f)
    [v_lin, ~, ~] = calc_rlos(a, 1e5, ifreq);
    v_lin = sqrt(2)*v_lin;
    v1 = v_lin(:,:,1);
    v2 = v_lin(:,:,2);
    plot_cdf(v1(:), 'g-');
    plot_cdf(v_iso(:,:,1,ifreq), 'r-');
    plot_cdf(v2(:), 'g-');
    plot_cdf(v_iso(:,:,2,ifreq), 'r-');
    plot_cdf(v_iso(:,:,3,ifreq), 'r-');
    plot_cdf(v_iso(:,:,4,ifreq), 'r-');

    v_lin_div = diversity('MRC', v_lin);
    plot_cdf(v_lin_div(:), 'g--');
    v_iso_div = diversity('MRC', v_iso);
    plot_cdf(v_iso_div(:), 'r--');
end
plot_cdf_rayleigh(1);
