close all;
clear;

ifreq = 1;

c.w = gen_waves('3D', 20, 1e5, 'Linear');

tmp = '../data/SonyEricsson/Laird_';
a{1} = read_farfield_sg64([tmp 'top_antenna_freespace.txt'     ], 0, 1e9);
a{2} = read_farfield_sg64([tmp 'bottom_antenna_freespace.txt'  ], 0, 1e9);
a{3} = read_farfield_sg64([tmp 'top_antenna_single_hand.txt'   ], 0, 1e9);
a{4} = read_farfield_sg64([tmp 'bottom_antenna_single_hand.txt'], 0, 1e9);

disp('Frequency [MHz]:');
disp(a{1}.f(ifreq)/1e6);
disp('Original efficiency [dB] single hand, port 1:');
disp(10*log10(a{3}.power.radiated(ifreq)/(4*pi)));
disp('Original efficiency [dB] single hand, port 2:');
disp(10*log10(a{4}.power.radiated(ifreq)/(4*pi)));

a = [normalize_power_radiated_2best(a(1:2)) ...
     normalize_power_radiated_2best(a(3:4))];
nAnt = numel(a);

c.a = [a{1} a{2} a{3} a{4}];
c.p = gen_positions([0 0 0 0],0,0,0,0,0);
v_iso = sqrt(2)*calc_v(c);

% Plot CDF curves for all frequencies.
h = figure;
plot_cdf_rayleigh(1);
plot_cdf_format();
[v_lin, ~, ~] = calc_rlos(a, 1e5, ifreq);
v_lin = sqrt(2)*v_lin;
for iAnt = 3:nAnt %%%
    v_los_tmp = v_lin(:,:,iAnt);
    v_iso_tmp = v_iso(:,:,iAnt,ifreq);
    plot_cdf(v_los_tmp(:), 'g-', 'LP LOS', 'dBR1');
    plot_cdf(v_iso_tmp(:), 'r-', 'RIMP', 'dBR1');
end
plot_cdf_rayleigh(1, 'MRC', 2);
for iDiv = 3 %%%
    v_los_div = diversity('MRC', v_lin(:,:,iDiv:iDiv+1));
    plot_cdf(v_los_div(:), 'g--', 'LP LOS', 'dBR1');
    v_iso_div = diversity('MRC', v_iso(:,:,iDiv:iDiv+1,:));
    plot_cdf(v_iso_div(:), 'r--', 'RIMP', 'dBR1');
end
plot_cdf_rayleigh(1);
legend('Rayleigh', 'LP LOS', 'RIMP', 'Location', 'southeast');
