close all;
clear;
reset(RandStream.getGlobalStream, 123);

% List of all Rician K-factors.
%kfactor_list = [Inf, 32, 16, 8, 4, 2, 1, 0.75, 0.5, 0.25, 0];
k_max = 100;
k_min = 1/k_max;
kfactor_list = logspace(log10(k_max),log10(k_min),100);

% Generate set of waves with many K-factors.
for ik = 1:numel(kfactor_list)
    w_tmp = gen_waves('3D', 20, 100, 'Linear', kfactor_list(ik));
    if ik==1
        c.w = w_tmp;
    else
        c.w.theta   = [c.w.theta   w_tmp.theta  ];
        c.w.phi     = [c.w.phi     w_tmp.phi    ];
        c.w.E_theta = [c.w.E_theta w_tmp.E_theta];
        c.w.E_phi   = [c.w.E_phi   w_tmp.E_phi  ];
    end
end
c.w.nRealizations = size(c.w.phi,2);

% Define antenna position, far-field and then calculate received voltage.
c.p = gen_positions(0, 0, 0, 0, 0, 0);
%c.a = gen_farfield('incremental Huygens source');
c.a = gen_farfield('incremental electric dipole');
c.v = calc_v(c);

% Plot overview of waves.
pow_matrix = hypot(c.w.E_theta, c.w.E_phi).^2;
figure;
imagesc(10*log10(pow_matrix));
caxis([-40 0]);
colormap(jet(256));
colorbar;
title('Power of incoming waves [dB]');
xlabel('Realization number');
ylabel('Wave in each realization');
%save_fig([mfilename '_pow_mat'], 16, 8);

% Plot CDF.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
axis([-50 10 1e-3 1e0]);
%save_fig([mfilename '_cdf'], 12);
