% Initialize
close all;
clear;

% Generate some data.
N = 1e4;
v = complex(randn(N,2), randn(N,2));
v(:,3) = sqrt(sum(abs(v(:,1:2)).^2, 2));  % MRC diversity combination
v(:,4) = max(v(:,1:2), [], 2);  % Max selection diversity combination
v(:,5) = min(v(:,1:2), [], 2);  % Min selection diversity combination

% Calculate

% Calculate CDF (cumulative distribution function).
p = sort(abs(v).^2, 1, 'ascend');
p_dB = 10*log10(p);
CDF = (1:N)' / N;

% Calculate Throughput (normalized).
pt = 1;
p_av = pt ./ p;
p_av_dB = 10*log10(p_av);
CCDF = 1-CDF;

% Calculate GER (group error rate).
GER = CDF;

% Plot

% Plot CDF curves.
figure;
semilogy(p_dB, CDF, 'LineWidth', 1);
axis([-40 20 1e-3 1e0]);
grid on;
title('CDF Plot');
xlabel('Power [dB]');
ylabel('CDF [-]');
legend('Antenna 1', 'Antenna 2', 'MRC', 'Max selection', 'Min selection', ...
    'Location', 'southeast');
%save_fig([mfilename '_CDF'], 12);

% Plot Throughput curves.
figure;
plot(p_av_dB, CCDF, 'LineWidth', 1);
axis([-20 40 0 1]);
grid on;
title('Throughput Plot');
xlabel('Average Power [dB]');
ylabel('TPUT [-]');
legend('Antenna 1', 'Antenna 2', 'MRC', 'Max selection', 'Min selection', ...
    'Location', 'southeast');
%save_fig([mfilename '_TPUT'], 12);

% Plot GER curves.
figure;
semilogy(p_av_dB, GER, 'LineWidth', 1);
axis([-20 40 1e-3 1e0]);
grid on;
title('GER Plot');
xlabel('Average Power [dB]');
ylabel('GER [-]');
legend('Antenna 1', 'Antenna 2', 'MRC', 'Max selection', 'Min selection', ...
    'Location', 'southwest');
%save_fig([mfilename '_GER'], 12);
