% Initialize
close all;
clear;

% Generate some data.
N = 1e4;
c1.w = gen_waves('3D', 20, N, 'Linear');  % TX1
c2.w = gen_waves('3D', 20, N, 'Linear');  % TX2
c1.p = gen_positions([-1 1], 0, 0, 0, 0, 0);
c2.p = c1.p;
c1.a = [gen_farfield('incremental electric dipole') ...
        gen_farfield('incremental electric dipole')];
c2.a = c1.a;
c1.v = calc_v(c1);
c2.v = calc_v(c2);

% Calculate

% Find eigenvalues.
H = zeros(2,2,N);
v = [squeeze(c1.v) squeeze(c2.v) complex(zeros(N,2))];
for i3 = 1:N
    H(:,1,i3) = c1.v(i3,:);  % TX1
    H(:,2,i3) = c2.v(i3,:);  % TX2
    [~,S,~] = svd(H(:,:,i3));
    v(i3,5:6) = diag(S);
end

% Calculate CDF (cumulative distribution function).
p = sort(abs(v).^2, 1, 'ascend');
p_dB = 10*log10(p);
CDF = (1:N)' / N;

% Calculate Throughput (normalized).
pt = 1;
p_av = pt ./ p;
p_av_dB = 10*log10(p_av);
CCDF = 1-CDF;

% Calculate GER (group error rate).
GER = CDF;

% Plot

% Plot CDF curves.
figure;
semilogy(p_dB, CDF, 'LineWidth', 1);
axis([-40 20 1e-3 1e0]);
grid on;
title('CDF Plot');
xlabel('Power [dB]');
ylabel('CDF [-]');
legend('TX1-RX1', 'TX1-RX2', 'TX2-RX1', 'TX2-RX2', 'Max Eigenv.', ...
    'Min Eigenv.', 'Location', 'southeast');
%save_fig([mfilename '_CDF'], 12);

% Plot Throughput curves.
figure;
plot(p_av_dB, CCDF, 'LineWidth', 1);
axis([-20 40 0 1]);
grid on;
title('Throughput Plot');
xlabel('Average Power [dB]');
ylabel('TPUT [-]');
legend('TX1-RX1', 'TX1-RX2', 'TX2-RX1', 'TX2-RX2', 'Max Eigenv.', ...
    'Min Eigenv.', 'Location', 'southeast');
%save_fig([mfilename '_TPUT'], 12);

% Plot GER curves.
figure;
semilogy(p_av_dB, GER, 'LineWidth', 1);
axis([-20 40 1e-3 1e0]);
grid on;
title('GER Plot');
xlabel('Average Power [dB]');
ylabel('GER [-]');
legend('TX1-RX1', 'TX1-RX2', 'TX2-RX1', 'TX2-RX2', 'Max Eigenv.', ...
    'Min Eigenv.', 'Location', 'southwest');
%save_fig([mfilename '_GER'], 12);
