close all;
clear;

N = ceil(1e5/(3*40));
antenna_type = 'incremental Huygens source';
%antenna_type = 'incremental electric dipole';

% Define waves.
c.w = gen_waves('Icosahedron', 20, N, 'Linear');

% Define positions.
p1 = gen_positions_platform(1.5, 40);
c.p = gen_positions([p1.x p1.x p1.x], p1.y, 0, p1.alpha, 0, 0);

% Define antennas.
a1 = gen_farfield(antenna_type);
a2 = rotate_farfield(a1, 0, pi/2,    0);
a3 = rotate_farfield(a1, 0, pi/2, pi/2);
c.a = [a1 a2 a3];

% Plot waves.
figure;
plot_waves(c.w, 1);
%save_fig([mfilename '_waves'], 16, 8);

% Plot overview of waves.
pow_matrix = hypot(c.w.E_theta, c.w.E_phi).^2;
figure;
imagesc(10*log10(pow_matrix));
caxis([-40 0]);
colormap(jet(256));
colorbar;
title('Power of incoming waves [dB]');
xlabel('Realization number');
ylabel('Wave in each realization');
%save_fig([mfilename '_pow_mat'], 16);

% Plot antenna patterns in positions.
figure;
plot_farfield(a1);
%save_fig([mfilename '_farfield1'], 16);
plot_farfield(a2);
%save_fig([mfilename '_farfield2'], 16);
plot_farfield(a3);
%save_fig([mfilename '_farfield3'], 16);

% Calculate voltages at port.
v = calc_v(c, 'spline');
c.v = v(:);

% Plot CDF.
figure;
plot_cdf_rayleigh();
plot_cdf_format();
plot_cdf(c.v);
%save_fig([mfilename '_cdf'], 16);
