close all;
clear;

N = 10000;
nWavesPerRealization_vector = 1:20;
c1.a = gen_farfield('incremental electric dipole');
c1.p = gen_positions(0, 0, 0, 0, 0, 0);


% Plot antenna far-fields.
figure;
plot_farfield(c1.a);

lgnds = cell(numel(nWavesPerRealization_vector), 1);
for ii = 1:numel(nWavesPerRealization_vector)
    M = nWavesPerRealization_vector(ii);

    % Generate waves.
    c1.w = gen_waves('3D', M, N, 'Linear', [], (90-15)*pi/180, (90+5)*pi/180, -45*pi/180, 45*pi/180);

    % Calculate voltages on ports.
    c1.v(:,ii) = calc_v(c1);

    lgnds(ii,:) = {sprintf('Vertical Dipole, M=%d', M)};
end

% Plot CDF of received voltage at antenna port.
h = figure;
plot_cdf(c1.v(:, [1 2 5 10 20]), '-');
plot_cdf_format();
plot_cdf_rayleigh(0.5);        % Add Theoretical Rayleigh to legend
legend(lgnds([1 2 5 10 20]), 'Location', 'southeast');

% Plot 1% level as a function of waves per realization.
one_percent_level_dB = get_cdf_level(c1.v, 'dB');
figure;
plot(nWavesPerRealization_vector, one_percent_level_dB, 'bo-');
grid on;
axis([0 20 -40 -15]);
xlabel('Waves per realization [-]');
ylabel('Received power at 1% CDF level [dB]');
