close all;
clear;

c.w = gen_waves('3D', 20, 1e5, 'Linear');

tmp = '../data/SonyEricsson/Laird_';
a{1} = read_farfield([tmp 'top_antenna_freespace.txt'     ]);
a{1}.f = a{1}.f(28);
a{1}.Eth = a{1}.Eth(:,:,28);
a{1}.Eph = a{1}.Eph(:,:,28);
a{2} = read_farfield([tmp 'bottom_antenna_freespace.txt'  ]);
a{2}.f = a{2}.f(28);
a{2}.Eth = a{2}.Eth(:,:,28);
a{2}.Eph = a{2}.Eph(:,:,28);
a{3} = read_farfield([tmp 'top_antenna_single_hand.txt'   ]);
a{3}.f = a{3}.f(28);
a{3}.Eth = a{3}.Eth(:,:,28);
a{3}.Eph = a{3}.Eph(:,:,28);
a{4} = read_farfield([tmp 'bottom_antenna_single_hand.txt']);
a{4}.f = a{4}.f(28);
a{4}.Eth = a{4}.Eth(:,:,28);
a{4}.Eph = a{4}.Eph(:,:,28);
a(1:2) = normalize_power_radiated_2best(a(1:2));
a(3:4) = normalize_power_radiated_2best(a(3:4));
nant = numel(a);

c.a = [a{1} a{2} a{3} a{4}];
c.p = gen_positions([0 0 0 0],0,0,0,0,0);
v_iso = sqrt(2)*calc_v(c);

% Plot CDF curves for all frequencies.
h = figure;
plot_cdf_rayleigh(1);
plot_cdf_format();
iFreq = 1;
[v_lin, ~, ~] = calc_rlos(a, 1e5, iFreq);
v_lin = sqrt(2)*v_lin;
for iAnt = 3:nant %%%
    v_los_tmp = v_lin(:,:,iAnt);
    v_iso_tmp = v_iso(:,:,iAnt,iFreq);
    plot_cdf(v_los_tmp(:), 'g-', 'LP LOS', 'dBR1');
    plot_cdf(v_iso_tmp(:), 'r-', 'RIMP', 'dBR1');
    p_los_dBR = get_cdf_level(v_los_tmp(:),'dBR1');
    p_iso_dBR = get_cdf_level(v_iso_tmp(:),'dBR1');
    fprintf('Random LOS, antenna %d, %5.1f dBR\n', iAnt, p_los_dBR);
    fprintf('RIMP, antenna %d, %5.1f dBR\n', iAnt, p_iso_dBR);
end
plot_cdf_rayleigh(1, 'MRC', 2);
for iDiv = 3 %%%
    v_los_div = diversity('MRC', v_lin(:,:,iDiv:iDiv+1));
    plot_cdf(v_los_div(:), 'g--', 'LP LOS', 'dBR1');
    v_iso_div = diversity('MRC', v_iso(:,:,iDiv:iDiv+1,:));
    plot_cdf(v_iso_div(:), 'r--', 'RIMP', 'dBR1');
    p_los_dBR = get_cdf_level(v_los_div(:),'dBR1');
    p_iso_dBR = get_cdf_level(v_iso_div(:),'dBR1');
    fprintf('Random LOS diversity, antenna %d-%d, %5.1f dBR\n', iDiv, iDiv+1, p_los_dBR);
    fprintf('RIMP diversity, antenna %d-%d, %5.1f dBR\n', iDiv, iDiv+1, p_iso_dBR);
end
plot_cdf_rayleigh(1);
legend('Rayleigh', '3D RLOS', 'RIMP', 'Location', 'southeast');
%save_fig('ahmed.png', 11);
