close all;
clear;

% Generate incoming waves.
N = 10000;
w = gen_waves('3D', 10, N, 'LinearVertical', [], (90-15)*pi/180, (90+5)*pi/180);

% Define sectors in azimuth.
sector_boundaries = pi/180*[-Inf -135 -45 45 135 Inf];
sector_weights    = sqrt(  [    6    3   1  2   6   ]);

% Modify incoming waves so that they are weighted according to sectors.
for ii = 1:numel(sector_weights)
    indx = w.phi>=sector_boundaries(ii) & w.phi<sector_boundaries(ii+1);
    w.E_theta(indx) = w.E_theta(indx) * sector_weights(ii);
    w.E_phi(indx)   = w.E_phi(indx)   * sector_weights(ii);
end

% Re-normalize power of incoming waves.
pow = sum(hypot(w.E_theta,w.E_phi).^2, 1);
norm_factor = 1 ./ repmat(sqrt(pow), w.nWavesPerRealization, 1);
w.E_theta = norm_factor .* w.E_theta;
w.E_phi = norm_factor .* w.E_phi;

% Check.
phi_bins = (-180:5:180)*pi/180;
pow = zeros(1, numel(phi_bins)-1);
for ii = 1:numel(phi_bins)-1
    indx =  w.phi>=phi_bins(ii) & w.phi<phi_bins(ii+1);
    pow(ii) = mean(hypot(w.E_theta(indx), w.E_phi(indx)).^2);
end
figure;
plot(phi_bins(1:end-1)*180/pi, pow);
