close all;
clear;

% Generate incoming waves with virmlab's normalization.
w = gen_waves('3D', 20, 10000, 'Linear');

% Check that the linear power sum for each realization is one (allowing for
% small numerical errors.
P = abs(w.E_theta).^2 + abs(w.E_phi).^2;
P_sum = sum(P, 1);  % sum all waves in each realization
tol = 1e-14;  % numerical tolerance
if all(abs(P_sum-1)<tol)
    disp(['virmlab normalizes so that the power sum of incoming waves for ' ...
        'each realization is one!']);
else
    error('This should not happen!');
end

% Generate isotropic antennas with orthogonal polarizations.
a1 = gen_farfield('isotropic theta');
a2 = gen_farfield('isotropic phi');

% Generate positions.
p = gen_positions(0,0,0,0,0,0);

% Case 1, isotropic theta-polarized antenna.
c1.w = w;
c1.p = p;
c1.a = a1;
v1 = calc_v(c1);
P1_mean = mean(abs(v1).^2);
fprintf(['A (loss-less) isotropic theta-polarized antenna will in ' ...
    'average receive a linear power of %.6f for these realizations.\n'], ...
    P1_mean);

% Case 2, isotropic phi-polarized antenna.
c2.w = w;
c2.p = p;
c2.a = a2;
v2 = calc_v(c2);
P2_mean = mean(abs(v2).^2);
fprintf(['A (loss-less) isotropic phi-polarized antenna will in ' ...
    'average receive a linear power of %.6f for these realizations.\n'], ...
    P2_mean);

fprintf('The sum is %.6f.\n', P1_mean+P2_mean);

%-------------------------------------------------------------------------------

% Step-by-step comparison with C-code.
NoWaves = w.nWavesPerRealization;
NoRealizations = w.nRealizations;

%// Compute first mean power value for an isotropic dual polarized reference
%// antenna
%// All power values are normalized with this value
%double RefPower = 0.0;
RefPower = 0.0;

%// Loop over realizations...
%for (int r=0; r<NoRealizations; r++)
%_{
for ir = 1:NoRealizations

    %// Sum over waves...
    %CVal pv1 = 0.0;  // Complex port voltage...
    %CVal pv2 = 0.0;  // Complex port voltage...
    pv1 = 0.0;
    pv2 = 0.0;
    
    %for (int w=0; w<NoWaves; w++)
    %_{
    for iw = 1:NoWaves
        
        %CVal E,Et,Ep;  // Complex amplitude
        %double theta,phi;  // Incident direction
        %double pol;  // Polarization (measured from plane of incidence)
        %E = EincMat[r][w].E;
        %%%theta = EincMat[r][w].theta;
        %%%phi = EincMat[r][w].phi;
        %pol = EincMat[r][w].pol;
        %Et = -E*cos(pol);  // Etheta
        %Ep = E*sin(pol);  // Ephi
        Et = w.E_theta(iw,ir);
        Ep = w.E_phi(iw,ir);
        %pv1 += Et;
        %pv2 += Ep;  // Ideal isotropic dual polarized antenna
        pv1 = pv1 + Et;
        pv2 = pv2 + Ep;
    %_}
    end
    %RefPower += abs(pv1)*abs(pv1) + abs(pv2)*abs(pv2); // Power proportional
    %// to voltage squared
    RefPower = RefPower + abs(pv1)*abs(pv1) + abs(pv2)*abs(pv2);
%_}
end
%RefPower = RefPower / (double) NoRealizations; // Mean power received by
%// isotropic dual polarized reference antenna
RefPower = RefPower / NoRealizations;

% It is the same reference power!!!
fprintf('The C-code gives RefPower = %.6f.\n', RefPower);
fprintf('virmlab''s normalization gives RefPower==1 (asymtotically).\n');
