function p = figpos(s)
%FIGPOS Figure position relative to screen for string input.
%
%   function p = figpos(s)
%
%   Return figure position "p" (a vector) for position "s" (a string).
%   The string "s" can be any of the following:
%   'big'    - gives a figure covering most of the screen
%   'left'   - a figure to the left of the screen, centered vertically
%   'right'  - a figure to the right of the screen, centered vertically
%   'middle' - a figure in the middle of the screen vertically

% By Ulf Carlberg.

sizScr = get(0, 'ScreenSize');
siz = sizScr + [10 50 -20 -60]; % add margins

if strcmpi(s, 'big')
    p = siz;
elseif strcmpi(s, 'left')
    p = round(siz.*[1 1 0.5 0.5] + [0 siz(4)*0.25 0 0]);
elseif strcmpi(s, 'right')
    p = round(siz.*[1 1 0.5 0.5] + [siz(3)*0.5 siz(4)*0.25 0 0]);
elseif strcmpi(s, 'middle')
    p = round(siz.*[1 1 1 0.7] + [0 siz(4)*0.2 0 0]);
else
    error('Unknown figure position string.');
end
