function c = gen_clusters(nPointsPerCluster, nClusters)
%GEN_CLUSTERS Generate cluster (WINNER model).
%
%   function c = gen_clusters(nPointsPerCluster, nClusters)

% By Ulf Carlberg.

sigmaPoints = 5;
polBalance = 1;

% Put each cluster in a big circle in the azimuth plane.
phi = linspace(0, 2*pi, nClusters+1);
xx = 70*cos(phi(1:end-1));
yy = 70*sin(phi(1:end-1));

% Define coordinates of cluster points.
c.x = repmat(xx, nPointsPerCluster, 1) + ...
    sigmaPoints*randn(nPointsPerCluster, nClusters);
c.y = repmat(yy, nPointsPerCluster, 1) + ...
    sigmaPoints*randn(nPointsPerCluster, nClusters);
c.z = sigmaPoints*randn(nPointsPerCluster, nClusters);
c.x = c.x(:);
c.y = c.y(:);
c.z = c.z(:);

% Define amplitude and phase of incoming waves.
Eth = complex(randn(nPointsPerCluster, nClusters), ...
              randn(nPointsPerCluster, nClusters));
Eph = complex(randn(nPointsPerCluster, nClusters), ...
              randn(nPointsPerCluster, nClusters));
Eth = Eth(:);
Eph = Eph(:);
          
% Normalize and make the theta- (vertical) and phi- (horizontal) components
% have a defined polariation balance.
Pth = sum(abs(Eth(:).^2));
Pph = sum(abs(Eph(:).^2));
weightTh = 1 / (Pth*(1+1/polBalance));
weightPh = 1 / (Pph*(1+polBalance));
c.E_theta = sqrt(weightTh)*Eth;
c.E_phi   = sqrt(weightPh)*Eph;
c.polarizationBalance = polBalance;

% Include dimensions in output structure.
c.nPointsPerCluster = nPointsPerCluster;
c.nClusters = nClusters;
c.nPoints = nPointsPerCluster*nClusters;
