function [xx, yy] = gen_grid(gridType, d, nRows, nCols)
%GEN_GRID Generates a 2D grid of points.
%
%   function [xx, yy] = gen_grid(gridType, d, nRows, nCols)
%
%   gridType - 'rectangular' or 'circular'
%   d        - distance between grid points
%   nRows    - number of rows
%   nCols    - number of columns (default = number of rows)

% By Ulf Carlberg.

if nargin<4 || isempty(nCols), nCols = nRows; end

% Generate a rectangular grid.
x = linspace(-d*(nRows-1)/2, d*(nRows-1)/2, nRows);
y = linspace(-d*(nCols-1)/2, d*(nCols-1)/2, nCols);
[xx, yy] = meshgrid(x, y);

if strcmpi(gridType, 'rectangular')
    % Do nothing, we are done!
elseif strcmpi(gridType, 'circular')    
    % Apply circular "mask".
    assert(nRows==nCols, ...
        'Number of columns must equal number of rows for a circular grid.');
    r = d*(nRows-1)/2;
    xx(hypot(xx, yy)>r) = NaN;
    yy(hypot(xx, yy)>r) = NaN;
else
    error('Unknown grid type.');
end
