function P = integrate_farfield(a)
%INTEGRATE_FARFIELD Power integration of antenna far-field structure.
%
%   function P = integrate_farfield(a)
%
%   Integrates the far-field function of antenna structure "a" to get the total
%   radiated power.

% By Ulf Carlberg.

% Interpolate with splines to increase accuracy.
theta = linspace(a.theta(1), a.theta(end), 181);
phi = linspace(a.phi(1), a.phi(end), 361);
[theta2D, phi2D] = ndgrid(theta, phi);
dtheta = theta(2) - theta(1);
dphi = phi(2) - phi(1);

% Integrate power density.
nFreq = size(a.Eth, 3);
P = zeros(nFreq, 1);
for iFreq = 1:nFreq
    W = hypot(a.Eth(:,:,iFreq), a.Eph(:,:,iFreq)).^2;
    W_interp = interp2_safe(a.phi, a.theta, W, phi2D, theta2D);
    P(iFreq) = dtheta*dphi*trapz(trapz(W_interp.*sin(theta2D)));
end
