function E_interp = interp2_safe(ph, th, E, ph_interp, th_interp, interp_method)
%INTERP2_SAFE Safe 2D interpolation.
%
%   function E_interp = interp2_safe(ph, th, E, ph_interp, th_interp, ...
%       interp_method)
%
%   Interpolate 2D data making sure all interpolation coordinates are within
%   the bounds of the given coordinates. "interp_method" default is spline.
%
%   See also INTERP2.

% By Ulf Carlberg.

if nargin<6 || isempty(interp_method), interp_method = 'spline'; end

tol = 1e-2;  % accept small numerical errors
assert(max(ph_interp(:))<=max(ph(:))+tol, 'Outside range: ph_interp too big.'  );
assert(min(ph_interp(:))>=min(ph(:))-tol, 'Outside range: ph_interp too small.');
assert(max(th_interp(:))<=max(th(:))+tol, 'Outside range: th_interp too big.'  );
assert(min(th_interp(:))>=min(th(:))-tol, 'Outside range: th_interp too small.');

E_interp = interp2(ph, th, E, ph_interp, th_interp, interp_method);

assert(all(~isnan(E_interp(:))), 'Result contains NaN.');
