function a = merge_farfields(a1, a2)
%MERGE_FARFIELDS Merge antenna far-field structures.
%
%   function a = merge_farfields(a1, a2)

% By Ulf Carlberg.

if ~isnan(a1.f) || ~isnan(a2.f)
    assert(all(abs(a1.f(:)-a2.f    (:))<1e-6), 'Frequencies different.');
end
assert(all(abs(a1.theta(:)-a2.theta(:))<1e-6), 'Theta angles different.');
assert(all(abs(a1.phi  (:)-a2.phi  (:))<1e-6), 'Phi angles different.');

% Save antenna type in structure.
a.type = 'farfield';
a.name = 'merged farfields';
a.info.generated = 'Far-field generated with virmlab.';

% Copy from antenna 1 (should be same as antenna 2).
a.f = a1.f;
a.theta = a1.theta;
a.phi = a1.phi;

% Superposition of the two antenna's farfields.
a.Eth = a1.Eth + a2.Eth;
a.Eph = a1.Eph + a2.Eph;

% Define the multiplicative directivity factor (in linear scale).
a.D0 = 1;

% Integrate the far-field to get the radiated power.
a.power.radiated = integrate_farfield(a);
