function pause_figure_animation(h, onoff)
%PAUSE_FIGURE_ANIMATION Pause an animation in a figure window by clicking with the mouse.
%
%   function pause_figure_animation(h, onoff)
%
%   pause_figure_animation(h) or pause_figure_animation(h, 'on') enables pause
%   by clicking in the figure with handle "h" during a figure animation.
%
%   pause_figure_animation(h, 'off') turns off the pause function. Do this
%   when the animation is finished.

% By Ulf Carlberg.

if nargin<2 || strcmpi(onoff, 'on')
    set(h, 'WindowButtonDownFcn', [...
        'global ispause; ' ...
        'if isempty(ispause) || ~ispause, ' ...
            'ispause = true; ' ...
            'while ispause, ' ...
                'pause(0.1); ' ...
            'end; ' ...
        'else ' ...
            'ispause = false; ' ...
        'end; ']);
elseif strcmpi(onoff, 'off')
    set(h, 'WindowButtonDownFcn', '');
else
    error('Unknown command onoff.');
end
    