function h = plot_cdf(v, plot_style, label, unit)
%PLOT_CDF Plot CDF of e.g. received voltages on antenna ports.
%
%   function h = plot_cdf(v, plot_style, label, unit)
%
%   Plot CDF (cumulative distribution function) for port voltages.
%   v          - voltages to plot
%   plot_style - (optional) plot style
%   label      - (optional) for recording level at 1% relative Rayleigh
%   unit       - (optional) for recording level at 1% relative Rayleigh

% By Ulf Carlberg.

if nargin<2, plot_style = ''; end
if nargin<3, label = '';      end
if nargin<4, unit = '';       end

x = 20*log10(sort(abs(squeeze(v)), 1, 'ascend'));
n = size(squeeze(v), 1);
y = (1:n)' / n;

h = semilogy(x, y, plot_style, 'LineWidth', 1);

% Take out values at CDF level 1% and store it in userdata.
if ~isempty(unit)
    x_dBR = get_cdf_level(v, unit);
    h = gcf();
    userdata = get(h, 'UserData');
    if ~isfield(userdata, 'one_percent_level'), userdata.one_percent_level = {}; end
    for x_dBR_el = x_dBR
        userdata.one_percent_level{end+1,1} = ...
            sprintf('%s (%s) %.1f %s (at CDF=0.01)', label, plot_style, x_dBR_el, unit);
    end
    set(h, 'UserData', userdata);
end
