close all;
clear;

% Choose two orthogonal dipoles as an example.
a1 = gen_farfield('incremental electric dipole', 40, 80);
a2 = rotate_farfield(a1, 0, pi/2, 0);  
assert(all(a1.theta(:)==a2.theta(:)) && all(a1.phi(:)==a2.phi(:)), ...
    'Antennas must be sampled at same theta and phi angles.');

% Original patterns.
W1 = hypot(a1.Eth, a1.Eph).^2;
W2 = hypot(a2.Eth, a2.Eph).^2;

% Treat nulls in the far-field (of antenna 1) special to get numerical stable calculations below.
tol = 1e-6;
is_null_point = W1 / max(W1(:)) < tol;
Eth1_no_nulls = a1.Eth;
Eph1_no_nulls = a1.Eph;
i_ok = find(~is_null_point, 1, 'first');
for ii = 1:numel(a1.Eth)
    if is_null_point(ii)
        Eth1_no_nulls(ii) = a1.Eth(i_ok);
        Eph1_no_nulls(ii) = a1.Eph(i_ok);
    else
        i_ok = ii;
    end
end

% Calculate help vectors.
norm_factor = 1 ./ hypot(Eth1_no_nulls, Eph1_no_nulls).^2;

% Correlated pattern.
W_corr = norm_factor .* abs(a2.Eth.*conj(Eth1_no_nulls) + a2.Eph.*conj(Eph1_no_nulls)).^2;
W_corr = W1 + W_corr;

% Uncorrelated pattern.
W_uncorr = norm_factor .* abs(-a2.Eth.*conj(Eph1_no_nulls) + a2.Eph.*conj(Eth1_no_nulls)).^2;

% Normalize to the maximum of all values we like to plot.
norm_factor_plot = 1 / max([W1(:) ; W2(:) ; W_corr(:) ; W_uncorr(:)]);
W1       = norm_factor_plot * W1;
W2       = norm_factor_plot * W2;
W_corr   = norm_factor_plot * W_corr;
W_uncorr = norm_factor_plot * W_uncorr;

% We need r_hat for plotting.
[x, y, z] = unit_vector_rhat(repmat(a1.theta,1,size(a1.phi,1)), repmat(a1.phi',size(a1.theta,1),1));

figure;
surf(x.*W1, y.*W1, z.*W1, W1); hold on;
surf(x.*W2, y.*W2, z.*W2, W2);
title('Both far-fields on top of each other');
shading interp;
caxis([0 1]); 
axis image;
axis off;
view(40, 20);
%print(gcf, '-dpng', [mfilename '_01_farfields']);

figure;
surf(x.*W_corr, y.*W_corr, z.*W_corr, W_corr); 
title('Correlated');
shading interp;
caxis([0 1]); 
axis image;
axis off;
view(40, 20);
%print(gcf, '-dpng', [mfilename '_02_correlated']);

figure;
surf(x.*W_uncorr, y.*W_uncorr, z.*W_uncorr, W_uncorr); 
shading interp;
title('Uncorrelated');
caxis([0 1]); 
axis image;
axis off;
view(40, 20);
%print(gcf, '-dpng', [mfilename '_03_uncorrelated']);
