function plot_farfield_inpos(c, plotFormat, shadingType, extraSeparationX)
%PLOT_FARFIELD_INPOS Plot far-field ("radiation pattern") of antenna in a translated position.
%
%   function plot_farfield_inpos(c, plotFormat, shadingType, extraSeparationX)
%
%   Plot radiation pattern of antenna in case "c" for each position defined in
%   case "c".
%
%   See also PLOT_FARFIELD.

% By Ulf Carlberg.

% Define optional input arguments if needed.
if nargin<2, plotFormat = [];      end
if nargin<3, shadingType = [];     end
if nargin<4, extraSeparationX = 0; end

% Plot far-field for each position.
hold on;
for iAnt = 1:size(c.p.x, 2)
    a = rotate_farfield(c.a(iAnt), c.p.alpha(1, iAnt), c.p.theta(1, iAnt), ...
        c.p.phi(1, iAnt));
    x = extraSeparationX*(iAnt-1);
    xyzTrans = [c.p.x(1, iAnt)+x c.p.y(1, iAnt) c.p.z(1, iAnt)];
    plot_farfield(a, plotFormat, shadingType, xyzTrans, 1, 0);
end
