function plot_parameter(param, c, i, legendsStrings)
%PLOT_PARAMETER Plot estimated ADG (apparent divesity gain), capacity, correlation, or MED (mean effective directivity).
%
%   function plot_parameter(param, c, i, legendsStrings)
%
%   Plot parameter "param" in case "c" for the first "i" samples. Also show
%   legends according to "legendStrings".

% By Ulf Carlberg.

% Optional input arguments.
if nargin<3 || isempty(i), i = numel(c.nSamplesVector); end
if nargin<4,               legendsStrings = {};         end

% Format plot for different parameters.
if strcmpi(param, 'adg1')
    semilogx(c.nSamplesVector(1:i), 10*log10(c.adg1(1:i, :).'), 'linewidth', 1);
    ylim([0 12]);
    title('Estimated Apparent Diversity Gain');
    ylabel('Estimated Apparent Diversity Gain [dB]');
    legendLocation = 'southwest';
elseif strcmpi(param, 'adg2')
    semilogx(c.nSamplesVector(1:i), 10*log10(c.adg2(1:i, :).'), 'linewidth', 1);
    ylim([0 12]);
    title('Estimated Apparent Diversity Gain');
    ylabel('Estimated Apparent Diversity Gain [dB]');
    legendLocation = 'southwest';
elseif strcmpi(param, 'adg3')
    semilogx(c.nSamplesVector(1:i), 10*log10(c.adg3(1:i, :).'), 'linewidth', 1);
    ylim([0 12]);
    title('Estimated Apparent Diversity Gain');
    ylabel('Estimated Apparent Diversity Gain [dB]');
    legendLocation = 'southwest';
elseif strcmpi(param, 'capacity')
    semilogx(c.nSamplesVector(1:i), c.capacity(1:i, :).', 'linewidth', 1);
    ylim([2 10]);
    title('Estimated Capacity (for SNR = 15 dB)');
    ylabel('Estimated Capacity [bits/s/Hz]');
    legendLocation = 'southwest';
elseif strcmpi(param, 'correlation')
    semilogx(c.nSamplesVector(1:i), abs(c.correlation(1:i, :).'), ...
        'linewidth', 1);
    ylim([0 1]);
    title('Estimated Correlation');
    ylabel('Correlation [-]');
    legendLocation = 'northeast';
elseif strcmpi(param, 'med')
    semilogx(c.nSamplesVector(1:i), 10*log10(c.med(1:i, :).'), 'linewidth', 1);
    ylim([-9 0]);
    title('Estimated Mean Effective Directivity');
    ylabel('Estimated MED [dB]');
    legendLocation = 'southeast';
else
    error('Unknown parameter.');
end

% Format plot (common for all parameters).
xlim([0 max(c.nSamplesVector)]);
grid on;
xlabel('Cumulative Number of Samples [-]');
if ~isempty(legendsStrings)
    legend(legendsStrings, 'Location', legendLocation);
end
