function h = plot_polar_farfield_phicut(a, iFreq, phi, plot_style)
%Polar plot for phi-cut

if nargin<2 || isempty(iFreq)     , iFreq = 1;       end
if nargin<3 || isempty(phi)       , phi = 0;         end
if nargin<4 || isempty(plot_style), plot_style = ''; end

% Check so plot format is ok.
userdata = get(gcf, 'UserData');
if ~strcmpi(userdata.plot_type, 'phicut')
    error('Wrong plot format.');
end

text(-1.25, 1.20, sprintf('\\phi = %.0f^\\circ', phi*180/pi), 'FontSize', 10);

% Format data to plot.
k = 181;
theta = linspace(-pi, pi, 2*k-1)';
phi1 = phi - pi;
if phi1<min(a.phi)
    phi1 = phi1 + 2*pi;
end
Eth_cut1 = interp2_safe(a.phi, a.theta, a.Eth(:,:,iFreq), phi1, -theta(1:k-1), 'spline');
Eph_cut1 = interp2_safe(a.phi, a.theta, a.Eph(:,:,iFreq), phi1, -theta(1:k-1), 'spline');
Eth_cut2 = interp2_safe(a.phi, a.theta, a.Eth(:,:,iFreq), phi , +theta(k:end), 'spline');
Eph_cut2 = interp2_safe(a.phi, a.theta, a.Eph(:,:,iFreq), phi , +theta(k:end), 'spline');
W_dB = 20*log10(hypot([Eth_cut1 ; Eth_cut2], [Eph_cut1 ; Eph_cut2]));

% Plot data.
h = plot_polar_data(pi/2-theta, W_dB, plot_style);
