function h = plot_polar_farfield_thetacut(a, iFreq, theta, plot_style)
%Polar plot for theta-cut

if nargin<2 || isempty(iFreq)     , iFreq = 1;       end
if nargin<3 || isempty(theta)     , theta = pi/2;    end
if nargin<4 || isempty(plot_style), plot_style = ''; end

% Check so plot format is ok.
userdata = get(gcf, 'UserData');
if ~strcmpi(userdata.plot_type, 'thetacut')
    error('Wrong plot format.');
end

text(-1.25, 1.20, sprintf('\\theta = %.0f^\\circ', theta*180/pi), 'FontSize', 10);

% Format data to plot.
phi = linspace(0, 2*pi, 361);
if min(a.phi)<-1, phi = phi - pi; end
Eth_cut = interp2_safe(a.phi, a.theta, a.Eth(:,:,iFreq), phi, theta, 'linear');
Eph_cut = interp2_safe(a.phi, a.theta, a.Eph(:,:,iFreq), phi, theta, 'linear');
W_dB = 20*log10(hypot(Eth_cut, Eph_cut));

% Plot data.
h = plot_polar_data(phi, W_dB, plot_style);
