function h = plot_stat(c, types_of_plots, type_of_curves)
%PLOT_STAT Statistical plots: Coupling, Power, CDF, PoD, GER
%
%   function h = plot_stat(c, types_of_plots, type_of_curves)
%
%   This function can generate several plots (all optional) with optional
%   MIMO/diversity curves.

% By Ulf Carlberg.

% Make index of which types of MIMO/diversity algorithms to plot.
indx = [];
for ii = 1:numel(type_of_curves)
    s = type_of_curves{ii};
    indx = [indx find(strncmpi(s, c.names, numel(s)))]; %#ok<AGROW>
end

% Define fields if not defined.
if ~isfield(c, 'P1_dB')
    c.P1_dB = -40;
end
if ~isfield(c, 'P2_dB')
    c.P2_dB = c.P1_dB + 70;
end

% Init vector with handles to figures.
h = zeros(1, numel(types_of_plots));

for iplot = 1:numel(types_of_plots)
    h(iplot) = figure;
    if strcmpi(types_of_plots{iplot}, 'Coupling')
        plot(c.tt_angle, c.P_dB(:,indx), 'LineWidth', 1);
        xlim([min(c.tt_angle) max(c.tt_angle)+1]);
        ylim([c.P1_dB c.P2_dB]);
        set(gca, 'XTick', min(c.tt_angle):45:max(c.tt_angle)+1);
        title('Coupling');
        xlabel('Platform angle [deg]');
        ylabel('Coupling [dB]');
    elseif strcmpi(types_of_plots{iplot}, 'Power')
        plot(c.tt_angle, c.P_dB(:,indx)-c.P_t_dB, 'LineWidth', 1);
        xlim([min(c.tt_angle) max(c.tt_angle)+1]);
        ylim([c.P1_dB c.P2_dB]);
        set(gca, 'XTick', min(c.tt_angle):45:max(c.tt_angle)+1);
        title('Power transfer relative threshold');
        xlabel('Platform angle [deg]');
        ylabel('P/P_t [dB]');
    elseif strcmpi(types_of_plots{iplot}, 'CDF')
        semilogy(c.P_sorted_dB(:,indx)-c.P_t_dB, c.CDF, 'LineWidth', 1);
        xlim([c.P1_dB c.P2_dB]);
        ylim([1e-2 1e0]);
        title('CDF of power transfer relative threshold');
        xlabel('P/P_t [dB]');
        ylabel('CDF [-]');
    elseif strcmpi(types_of_plots{iplot}, 'PoD')
        plot(c.P_av_dB(:,indx), c.CCDF, 'LineWidth', 1);
        xlim([c.P_t_dB-c.P2_dB c.P_t_dB-c.P1_dB]);
        ylim([0 1]);
        title('Probability of Detection');
        xlabel('P_{av}/P_t [dB]');
        ylabel('Probability of Detection [-]');
    elseif strcmpi(types_of_plots{iplot}, 'GER')
        semilogy(c.P_av_dB(:,indx), c.CDF, 'LineWidth', 1);
        xlim([c.P_t_dB-c.P2_dB c.P_t_dB-c.P1_dB]);
        ylim([1e-2 1e0]);
        title('Group Error Rate');
        xlabel('P_{av}/P_t [dB]');
        ylabel('Group error rate [-]');
    end
    grid on;
    legend(c.names(indx), 'Location', 'southeast');
    drawnow;
end

end
