function h = plot_stat_filled_PoD(c)
%PLOT_STAT_FILLED_POD Statistical plot: PoD filled
%
%   function h = plot_stat_filled_PoD(c)
%
%   This function generate filled PoD curves from SVD.

% By Ulf Carlberg.

% Help variables.
P2_range_dB = [c.P_t_dB-c.P2_dB c.P_t_dB-c.P1_dB];
indx = find(strncmpi('SVD', c.names, 3));

% Extend this if more than four streams are needed.
clrs = [1 1 0 ; 0 1 0 ; 1 0 0 ; 0 0 1];
lgnds = {'One stream', 'Two streams', 'Three streams', 'Four streams'};

% Plot areas. Make manual grid lines on top of areas.
h = figure;
for ii = 1:numel(indx)
    area([P2_range_dB(2) ; c.P_av_dB(1,indx(ii)) ; c.P_av_dB(:,indx(ii))], ...
        [1 ; 1 ; c.CCDF], 'FaceColor', clrs(ii,:), 'LineWidth', 1);
    hold on;
end
xlim(P2_range_dB);
ylim([0 1]);
for y = 0.1:0.1:0.9
    plot(P2_range_dB, [y y], 'k:', 'LineWidth', 0.25);
    plot(P2_range_dB(2)-[0.012*diff(P2_range_dB) 0], [y y], 'k-', ...
        'LineWidth', 0.5);
end
for x = P2_range_dB(1)+10:10:P2_range_dB(2)-10
    plot([x x], [0 1], 'k:', 'LineWidth', 0.25);
    plot([x x], [0 0.015], 'k-', 'LineWidth', 0.5);
    plot([x x], [1 0.985], 'k-', 'LineWidth', 0.5);
end
title('Probability of Detection');
xlabel('Average Power [dB]');
ylabel('Probability of Detection [-]');
legend(lgnds{1:numel(indx)}, 'Location', 'southeast');
drawnow;

end
