function ppt_add_image(s, pos, filename)
%PPT_ADD_IMAGE Add an image to current PowerPoint slide.
%   
%   function ppt_add_image(s, pos, filename)
%
%   Add the image with "filename" in position "pos" to the slide "s". "pos" may
%   be 'C', 'NW', 'NE', 'SW', 'SE'.
%
%   See also PPT_CREATE and PPT_APPEND_SLIDE.

% By Ulf Carlberg.

if nargin<2 ||isempty(pos),      pos = 'C';                                      end
if nargin<3 ||isempty(filename)
    filename = [getenv('TEMP') '\matlabplot_tmp.png'];
end

% Accept numbers for position.
if isa(pos, 'numeric')
    pos_str = {'C', 'NW', 'NE', 'SW', 'SE'};
    pos = pos_str(pos+1);
end

% Slide layout [pixels].
slide_width  = s.Parent.SlideMaster.Width;
slide_height = s.Parent.SlideMaster.Height;
title_height = 110;
border       =   5;

% Area for plotting.
x = border;
y = title_height + border;
w = slide_width - 2*border;
h = slide_height - title_height - 2*border;

if strcmpi(pos, 'C')
    % Use complete area for plotting.
elseif strcmpi(pos, 'NW')
    w = floor(w/2) - 2*border;
    h = floor(h/2) - 2*border;
    x = x + 1*border;
    y = y + 1*border;
elseif strcmpi(pos, 'NE')
    w = floor(w/2) - 2*border;
    h = floor(h/2) - 2*border;
    x = x + 3*border + w;
    y = y + 1*border;
elseif strcmpi(pos, 'SW')
    w = floor(w/2) - 2*border;
    h = floor(h/2) - 2*border;
    x = x + 1*border;
    y = y + 3*border + h;
elseif strcmpi(pos, 'SE')
    w = floor(w/2) - 2*border;
    h = floor(h/2) - 2*border;
    x = x + 3*border + w;
    y = y + 3*border + h;
else
    error('Unknown position.');
end

% Adjust plot area so that we keep aspect ratio of image.
inf = imfinfo(filename);
wf = inf.Width;
hf = inf.Height;
f = min(w/wf, h/hf);
wa = floor(f*wf);
ha = floor(f*hf);
x = x + floor((w-wa)/2);
y = y + floor((h-ha)/2);

% Add image to current slide.
filename(filename=='/') = '\';
s.Shapes.AddPicture(filename, 'msoFalse', 'msoTrue', x, y, wa, ha);
