function data = read_ascii_file(filename, nheaderlines)
%READ_ASCII_FILE Read ASCII file with float numbers
%
%   function data = read_ascii_file(filename, nheaderlines)
%
%   Read file given by "filename", ignoring the first headlines given by
%   "nheaderlines". Output a 2D matrix with numeric data. This function is
%   optimized for speed.

% By Ulf Carlberg.

% Open file, read it, close it.
f = fopen(filename);
for ii = 1:nheaderlines
    fgetl(f);  % ignore headerline
end
ncolumns = numel(sscanf(fgetl(f),'%f'));  % find number of columns
fseek(f, 0, 'bof');  % go back to beginning of file
rawdata = textscan(f, '%f', 'HeaderLines', nheaderlines);
fclose(f);

% Provide data in 2D matrix.
data = reshape(rawdata{1}, ncolumns, [])';

end
