function a = set_power_radiated(a, pow)
%set_power_radiated: Set radiated power of antenna structure.
%
%   function a = set_power_radiated(a, pow)
%
%   Set radiated power "pow" of antenna structure "a". Use pow=4*pi for a
%   lossless antenna (default).

% By Ulf Carlberg.

if nargin<2, pow = 4*pi; end

nFreq = size(a.Eth,3);
if numel(pow)==1
    pow = repmat(pow, nFreq, 1);
end
pow_old = integrate_farfield(a);
norm_factors = sqrt(pow./pow_old);
for iFreq = 1:size(a.Eth,3)
    a.Eth(:,:,iFreq) = norm_factors(iFreq) * a.Eth(:,:,iFreq);
    a.Eph(:,:,iFreq) = norm_factors(iFreq) * a.Eph(:,:,iFreq);
end
a.power.radiated = pow;
