function xx = xmat(x, newSize)
%XMAT Expand a matrix to a new size defined by the user.
%
%   function xx = xmat(x, newSize)
%
%   Expand matrix "x" to "xx". "xx" will get the size "newSize".
%
%   Example:
%   If a = [8 1 6
%           3 5 7
%           4 9 2]
%   then xmat(a, [4 5]) is [8 1 6 8 1
%                           3 5 7 3 5
%                           4 9 2 4 9
%                           8 1 6 8 1].
%
%   See also REPMAT.

% By Ulf Carlberg.

oldSize = size(x);

% Make sure size vectors have equal lengths.
N = max(length(newSize), length(oldSize));
oldSize = [oldSize ones(1, N-length(oldSize))];
newSize = [newSize ones(1, N-length(newSize))];

% Expand matrix.
xx = repmat(x, ceil(newSize./oldSize));

% Pick out submatrix (if needed).
if any(mod(newSize, oldSize))
    subs = cell(1, length(newSize));
    for ii = 1:length(newSize)
        subs{ii} = 1:newSize(ii);
    end
    xx = xx(subs{:});
end
