function [x2, y2, z2] = zyzrot(x, y, z, alpha, theta, phi)
%ZYZROT Rotate coordinates with Euler angles, e.g. rotation of antenna far-field functions.
%
%   function [x2, y2, z2] = zyzrot(x, y, z, alpha, theta, phi)
%
%   Rotates objects with coordinates "x", "y", and "z" around the fixed unit
%   axes.
%   1. Rotate around the (fixed) z-axis with "alpha" radians.
%   2. Rotate around the (fixed) y-axis with "theta" radians.
%   3. Rotate around the (fixed) z-axis (again) with "phi" radians.
%
%   With these three rotations, any orientation of a rigid body can be
%   achieved.

% By Ulf Carlberg.

% This can be done slightly faster with a rotation matrix, but then the code
% becomes less intuitive to understand.

% Rotate around the z-axis with "alpha" radians.
[x2, y2] = local_rot2D(x, y, alpha);

% Rotate around the y-axis with "theta" radians. (Note the z-x order.)
[z2, x2] = local_rot2D(z, x2, theta);

% Rotate around the z-axis (again) with "phi" radians.
[x2, y2] = local_rot2D(x2, y2, phi);



%------------------------------------------------------------------------------
function [x2, y2] = local_rot2D(x, y, v)
% Rotates the coordinates "x" and "y" with the angle "v" (counter-clockwise).
x2 = x.*cos(v) - y.*sin(v);
y2 = x.*sin(v) + y.*cos(v);
%------------------------------------------------------------------------------
